from enum import IntFlag

from . import D3D12_2 as __wrapper_module__
from .D3D12_2 import (
    D3D12_SHADING_RATE_2X2,
    D3D12_FILTER_COMPARISON_MIN_POINT_MAG_MIP_LINEAR,
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_GENERIC_READ, D3D12_RANGE,
    D3D_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST,
    D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_EXTENSION_COMMAND,
    D3D11_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST,
    D3D12_FEATURE_QUERY_META_COMMAND,
    D3D12_QUERY_TYPE_PIPELINE_STATISTICS1,
    D3D12_FEATURE_ROOT_SIGNATURE,
    D3D12_ROOT_SIGNATURE_FLAG_ALLOW_STREAM_OUTPUT,
    D3D12_COMMAND_SIGNATURE_DESC, ID3D12Device3,
    D3D11_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST,
    DXGI_FORMAT_R8G8B8A8_UINT, __MIDL___MIDL_itf_d3d12_0000_0003_0005,
    D3D12_VIEWPORT,
    D3D12_ROOT_SIGNATURE_FLAG_DENY_MESH_SHADER_ROOT_ACCESS,
    D3D12_STATE_SUBOBJECT_TYPE_DXIL_SUBOBJECT_TO_EXPORTS_ASSOCIATION,
    D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_SUBRESOURCE_PARAMETERS,
    DXGI_FORMAT_R16_FLOAT, D3D10_PRIMITIVE_TOPOLOGY_POINTLIST,
    D3D12_INDIRECT_ARGUMENT_TYPE_INDEX_BUFFER_VIEW,
    D3D12_FILTER_MIN_MAG_MIP_POINT, D3D12_HEAP_DESC,
    D3D12_FILTER_COMPARISON_MIN_MAG_LINEAR_MIP_POINT,
    D3D12_CONSERVATIVE_RASTERIZATION_MODE_OFF,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_COMPACTION,
    D3D12_RESOLVE_MODE_MAX, D3D12_RESOURCE_DESC1,
    D3D12_RTV_DIMENSION_BUFFER, D3D12_DESCRIPTOR_HEAP_TYPE_NUM_TYPES,
    D3D12_PROTECTED_SESSION_STATUS_INVALID,
    D3D12_RENDER_PASS_FLAG_ALLOW_UAV_WRITES,
    D3D12_RESOURCE_STATE_VIDEO_DECODE_WRITE, D3D12_HEAP_TYPE_READBACK,
    D3D_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_VISUALIZATION_DECODE_FOR_TOOLS,
    D3D12_FEATURE_ARCHITECTURE1, D3D12_BLEND_SRC1_ALPHA,
    D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT,
    D3D12_COMPARISON_FUNC_ALWAYS,
    D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_WRITE,
    ID3D12GraphicsCommandList,
    D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT64,
    D3D12_AUTO_BREADCRUMB_OP_DRAWINDEXEDINSTANCED,
    D3D12_GRAPHICS_STATE_NONE, D3D12_LOGIC_OP_SET,
    D3D12_CPU_PAGE_PROPERTY_WRITE_COMBINE,
    D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP, HRESULT,
    D3D12_SHADER_CACHE_CONTROL_FLAG_DISABLE,
    D3D12_FILTER_MAXIMUM_MIN_MAG_POINT_MIP_LINEAR,
    D3D12_RENDER_PASS_BEGINNING_ACCESS,
    D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_BACKGROUND_WORK,
    D3D12_COMMAND_LIST_TYPE_VIDEO_DECODE,
    D3D_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST,
    D3D12_SHADER_VISIBILITY_PIXEL,
    D3D11_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST,
    D3D12_AUTO_BREADCRUMB_OP_WRITEBUFFERIMMEDIATE,
    D3D_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST,
    D3D12_INDIRECT_ARGUMENT_TYPE_DRAW, D3D12_DEPTH_STENCIL_DESC,
    D3D12_RTV_DIMENSION_UNKNOWN, COMMETHOD,
    D3D12_META_COMMAND_PARAMETER_TYPE_GPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV,
    DXGI_FORMAT_R8G8_B8G8_UNORM, D3D12_RESOURCE_DESC,
    D3D12_FEATURE_D3D12_OPTIONS9, DXGI_FORMAT_R8_SINT,
    D3D12_TILE_MAPPING_FLAG_NONE, D3D12_HEAP_TYPE_CUSTOM,
    D3D12_RESOURCE_ALLOCATION_INFO,
    D3D_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST,
    ID3D12GraphicsCommandList5,
    D3D11_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST,
    D3D12_DESCRIPTOR_HEAP_TYPE_CBV_SRV_UAV,
    D3D12_TILE_MAPPING_FLAG_NO_HAZARD,
    D3D12_FILTER_MINIMUM_MIN_MAG_MIP_LINEAR,
    D3D12_DSV_FLAG_READ_ONLY_STENCIL,
    D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_STATIC_KEEPING_BUFFER_BOUNDS_CHECKS,
    D3D12_RESOURCE_BARRIER_TYPE_ALIASING, ULONG_PTR,
    D3D12_STATIC_SAMPLER_DESC, D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH,
    D3D12_TEX3D_RTV, DXGI_FORMAT_BC1_UNORM,
    D3D12_RESIDENCY_FLAG_DENY_OVERBUDGET,
    D3D12_RENDER_TARGET_BLEND_DESC, DXGI_FORMAT_BC4_UNORM,
    D3D12_QUERY_TYPE_SO_STATISTICS_STREAM1, DXGI_FORMAT_R32_UINT,
    D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ, D3D12_TEX1D_RTV,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_ESTIMATOR,
    D3D12_RENDER_PASS_ENDING_ACCESS, D3D12_TEX2DMS_ARRAY_DSV,
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COMMON,
    D3D12_RESOURCE_STATE_PREDICATION,
    D3D12_UAV_DIMENSION_TEXTURE1DARRAY, D3D_ROOT_SIGNATURE_VERSION_1,
    D3D12_AUTO_BREADCRUMB_OP_DISPATCH,
    D3D12_RESOURCE_STATE_VIDEO_PROCESS_WRITE, DXGI_FORMAT_BC5_SNORM,
    D3D12_RESOURCE_FLAG_ALLOW_CROSS_ADAPTER,
    D3D12_INDIRECT_ARGUMENT_TYPE_SHADER_RESOURCE_VIEW,
    D3D12_DRED_ALLOCATION_TYPE_QUERY_HEAP,
    D3D12_FILTER_MIN_POINT_MAG_MIP_LINEAR,
    D3D11_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST,
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_POINT, D3D12_LOGIC_OP_AND_INVERTED,
    D3D12_BUFFER_SRV_FLAG_RAW,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_UPDATE,
    DXGI_FORMAT_Y216, D3D12_AUTO_BREADCRUMB_OP_BEGINEVENT,
    __MIDL___MIDL_itf_d3d12_0000_0001_0005,
    D3D_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST,
    D3D12_BLEND_SRC1_COLOR, D3D12_DRED_ALLOCATION_TYPE_STATE_OBJECT,
    D3D12_GRAPHICS_STATE_PREDICATION,
    D3D12_STATE_SUBOBJECT_TYPE_MAX_VALID, DXGI_FORMAT_BC7_UNORM_SRGB,
    STRING, D3D12_RASTERIZER_DESC, DXGI_FORMAT_BC2_TYPELESS,
    D3D12_RESOURCE_BARRIER, D3D12_QUERY_TYPE_BINARY_OCCLUSION,
    D3D_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST,
    DXGI_FORMAT_P010, D3D12_FEATURE_FORMAT_SUPPORT,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_BOTTOM_LEVEL,
    D3D_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST,
    DXGI_FORMAT_R32G32B32A32_TYPELESS,
    D3D12_AUTO_BREADCRUMB_OP_SETMARKER,
    D3D_PRIMITIVE_TOPOLOGY_LINELIST,
    D3D12_META_COMMAND_PARAMETER_STAGE_EXECUTION,
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_RESOLVE,
    D3D12_HEAP_FLAG_SHARED, DXGI_FORMAT_R10G10B10_XR_BIAS_A2_UNORM,
    D3D12_FILTER_MAXIMUM_MIN_MAG_LINEAR_MIP_POINT,
    D3D12_STENCIL_OP_INVERT, tagRECT, D3D12_ROOT_DESCRIPTOR_TABLE1,
    D3D12_HEAP_FLAG_NONE, D3D12_AUTO_BREADCRUMB_OP_ENDEVENT,
    D3D12_SUBRESOURCE_RANGE_UINT64, D3D12_BOX,
    D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_PARAMETERS,
    D3D12_ROOT_SIGNATURE_FLAG_DENY_GEOMETRY_SHADER_ROOT_ACCESS,
    DXGI_FORMAT_R8G8_SNORM, D3D12_SHADER_VISIBILITY_VERTEX,
    D3D12_HEAP_TYPE_UPLOAD,
    D3D_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST,
    D3D_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST,
    D3D12_SHADER_CACHE_MODE_MEMORY, D3D12_FILL_MODE_SOLID,
    D3D12_COMMAND_LIST_TYPE_COMPUTE, _SECURITY_ATTRIBUTES,
    D3D12_UAV_DIMENSION_BUFFER,
    D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_POINT,
    D3D12_INDIRECT_ARGUMENT_TYPE_UNORDERED_ACCESS_VIEW,
    D3D12_RESOURCE_STATE_VIDEO_DECODE_READ,
    D3D12_AUTO_BREADCRUMB_OP_ENDSUBMISSION,
    D3D12_COMPARISON_FUNC_NEVER, D3D_ROOT_SIGNATURE_VERSION_1_1,
    DXGI_FORMAT_BC4_TYPELESS, D3D12_STENCIL_OP_DECR,
    DXGI_FORMAT_R8G8_UNORM, D3D12_RESOURCE_STATE_ALL_SHADER_RESOURCE,
    D3D12_FILL_MODE_WIREFRAME,
    D3D12_RESOURCE_STATE_VIDEO_ENCODE_WRITE,
    DXGI_FORMAT_R16G16B16A16_UINT, ID3D12RootSignatureDeserializer,
    D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS1, DXGI_FORMAT_V408,
    D3D12_SHADING_RATE_2X4, ID3D12DeviceChild,
    D3D12_BARRIER_LAYOUT_VIDEO_QUEUE_COMMON,
    D3D12_RESOURCE_BARRIER_FLAG_END_ONLY, D3D12_SHADING_RATE_1X2,
    DXGI_FORMAT_R10G10B10A2_TYPELESS, D3D12_META_COMMAND_DESC,
    D3D12_RESOURCE_DIMENSION_UNKNOWN,
    D3D12_HEAP_FLAG_ALLOW_ONLY_NON_RT_DS_TEXTURES,
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEBUNDLE, D3D12_LOGIC_OP_OR,
    ID3D12Heap, D3D12_SHADER_VISIBILITY_MESH,
    D3D12_AUTO_BREADCRUMB_OP_RESOURCEBARRIER,
    D3D12_DRED_ALLOCATION_TYPE_FENCE, D3D12_FEATURE_FEATURE_LEVELS,
    D3D12_SHADING_RATE_2X1,
    D3D12_AUTO_BREADCRUMB_OP_SETPIPELINESTATE1,
    D3D12_ROOT_DESCRIPTOR_TABLE,
    D3D11_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST,
    D3D12_RESOURCE_STATE_RENDER_TARGET, ID3D12Device2,
    D3D12_STATE_OBJECT_TYPE_COLLECTION, DXGI_FORMAT_P016,
    D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES,
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_SIGNATURE,
    D3D12_FILTER_MINIMUM_ANISOTROPIC,
    D3D12_STATE_SUBOBJECT_TYPE_GLOBAL_ROOT_SIGNATURE,
    D3D12_STATE_SUBOBJECT_TYPE_DXIL_LIBRARY,
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_ALLOCATOR,
    D3D11_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST,
    D3D12_CPU_PAGE_PROPERTY_UNKNOWN,
    __MIDL___MIDL_itf_d3d12_0000_0034_0002,
    D3D12_GPU_DESCRIPTOR_HANDLE, D3D12_BUFFER_SRV_FLAG_NONE,
    D3D12_SHADER_CACHE_SESSION_DESC, D3D12_COMPARISON_FUNC_EQUAL,
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEEXTENSIONCOMMAND, D3D12_TEX1D_UAV,
    DXGI_FORMAT_R8G8_TYPELESS, D3D12_FEATURE_D3D12_OPTIONS1,
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_NO_ACCESS,
    D3D12_TILE_REGION_SIZE,
    D3D12_AUTO_BREADCRUMB_OP_INITIALIZEEXTENSIONCOMMAND,
    DXGI_FORMAT_R8_SNORM,
    D3D_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST,
    D3D12_MEMORY_POOL_L0,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_DESERIALIZE,
    D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT,
    D3D12_RTV_DIMENSION_TEXTURE1DARRAY,
    D3D12_HEAP_FLAG_DENY_NON_RT_DS_TEXTURES,
    D3D12_INDIRECT_ARGUMENT_TYPE_DRAW_INDEXED,
    D3D12_LOGIC_OP_COPY_INVERTED,
    D3D12_AUTO_BREADCRUMB_OP_RESOLVEQUERYDATA,
    D3D12_FENCE_FLAG_NON_MONITORED, D3D12_BLEND_OP_MAX,
    D3D12_META_COMMAND_PARAMETER_FLAG_OUTPUT,
    D3D12_FEATURE_MULTISAMPLE_QUALITY_LEVELS, D3D12_TEX1D_SRV,
    DXGI_FORMAT_B8G8R8A8_UNORM,
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_RECORDER,
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ, D3D12_TEXCUBE_SRV,
    D3D12_BLEND_ZERO, D3D12_AUTO_BREADCRUMB_OP_COPYTILES,
    D3D12_LIFETIME_STATE_NOT_IN_USE,
    D3D11_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST,
    D3D_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST,
    D3D12_TILE_SHAPE, ID3D12Device1, D3D12_DSV_FLAG_READ_ONLY_DEPTH,
    D3D11_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST,
    D3D12_FILTER_MIN_MAG_POINT_MIP_LINEAR,
    D3D12_RESOURCE_FLAG_ALLOW_SIMULTANEOUS_ACCESS,
    D3D10_PRIMITIVE_TOPOLOGY_UNDEFINED, D3D12_BLEND_INV_BLEND_FACTOR,
    D3D12_FILTER_MINIMUM_MIN_POINT_MAG_MIP_LINEAR,
    DXGI_FORMAT_R8G8_UINT, D3D12_COMPARISON_FUNC_GREATER,
    ID3D12VirtualizationGuestDevice,
    D3D12_CONSERVATIVE_RASTERIZATION_MODE_ON,
    D3D12_COMMAND_LIST_TYPE_VIDEO_PROCESS,
    D3D12_RENDER_PASS_BEGINNING_ACCESS_CLEAR_PARAMETERS,
    DXGI_FORMAT_R16_UINT,
    D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE,
    D3D12_DRED_PAGE_FAULT_OUTPUT1,
    D3D12_HEAP_FLAG_ALLOW_SHADER_ATOMICS,
    D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR,
    D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES1,
    D3D12_RESOURCE_FLAG_ALLOW_RENDER_TARGET, DXGI_FORMAT_R16G16_FLOAT,
    D3D12_BLEND_INV_DEST_ALPHA, ID3D12CommandAllocator,
    D3D12_STATIC_BORDER_COLOR_OPAQUE_WHITE,
    D3D12_TILE_COPY_FLAG_SWIZZLED_TILED_RESOURCE_TO_LINEAR_BUFFER,
    ID3D12ProtectedSession, DXGI_FORMAT_R32G32B32_TYPELESS,
    D3D12_META_COMMAND_PARAMETER_TYPE_UINT64,
    DXGI_FORMAT_R11G11B10_FLOAT,
    __MIDL___MIDL_itf_d3d12_0000_0003_0002,
    D3D12_DSV_DIMENSION_TEXTURE2DMS,
    D3D_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST,
    D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME, D3D12_BLEND_ONE,
    D3D12_CACHED_PIPELINE_STATE,
    D3D12_SHADER_CACHE_CONTROL_FLAG_CLEAR, ID3D12GraphicsCommandList6,
    D3D12_META_COMMAND_PARAMETER_TYPE_GPU_VIRTUAL_ADDRESS,
    D3D12_RESOURCE_BARRIER_TYPE_TRANSITION, WSTRING,
    D3D12_SRV_DIMENSION_TEXTURE3D,
    D3D12_DRIVER_MATCHING_IDENTIFIER_COMPATIBLE_WITH_DEVICE,
    DXGI_FORMAT_R32G32_TYPELESS, D3D12_BLEND_INV_SRC1_ALPHA,
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_QUEUE, D3D12_TEX2D_ARRAY_UAV,
    D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT,
    D3D11_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST,
    D3D12_MEMORY_POOL_UNKNOWN,
    D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFF,
    D3D12_BLEND_INV_ALPHA_FACTOR,
    D3D12_STATE_OBJECT_TYPE_RAYTRACING_PIPELINE,
    D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS, D3D12_BUFFER_RTV,
    D3D12_LOGIC_OP_EQUIV, D3D12_BARRIER_LAYOUT_SHADING_RATE_SOURCE,
    __MIDL___MIDL_itf_d3d12_0000_0001_0009,
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_DISCARD,
    D3D12_RESOURCE_STATE_COMMON, DXGI_FORMAT_X24_TYPELESS_G8_UINT,
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ, D3D12_ROOT_DESCRIPTOR,
    D3D12_HEAP_FLAG_DENY_RT_DS_TEXTURES, D3D12_FEATURE_D3D12_OPTIONS7,
    D3D12_QUERY_TYPE_OCCLUSION,
    D3D12_RAYTRACING_GEOMETRY_TYPE_TRIANGLES,
    D3D12_TILE_RANGE_FLAG_REUSE_SINGLE_TILE,
    D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_LINEAR,
    DXGI_FORMAT_B8G8R8A8_UNORM_SRGB,
    D3D11_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST,
    D3D12_RESOURCE_FLAG_VIDEO_DECODE_REFERENCE_ONLY,
    D3D12_LOGIC_OP_OR_INVERTED, D3D12_DRED_ALLOCATION_TYPE_PASS,
    D3D12_QUERY_TYPE_PIPELINE_STATISTICS, DXGI_FORMAT_BC3_UNORM_SRGB,
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST,
    D3D12_AUTO_BREADCRUMB_OP_CLEARDEPTHSTENCILVIEW,
    __MIDL___MIDL_itf_d3d12_0000_0003_0006,
    D3D12_FEATURE_SERIALIZATION, DXGI_FORMAT_R32G32B32_FLOAT,
    DXGI_FORMAT_R24_UNORM_X8_TYPELESS, D3D12_TEX2D_SRV,
    D3D12_TEX2D_ARRAY_RTV, DXGI_FORMAT_R32G32B32A32_FLOAT,
    DXGI_FORMAT_B8G8R8X8_UNORM_SRGB, D3D12_UAV_DIMENSION_TEXTURE3D,
    D3D12_STATE_SUBOBJECT_TYPE_LOCAL_ROOT_SIGNATURE, ID3D12Device8,
    DXGI_FORMAT_R16G16B16A16_FLOAT, D3D12_BUFFER_UAV_FLAG_RAW,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_CLONE,
    D3D12_FILTER_COMPARISON_ANISOTROPIC,
    D3D12_RESOURCE_STATE_INDEX_BUFFER,
    D3D12_DRED_ALLOCATION_TYPE_RESOURCE,
    D3D11_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST,
    D3D12_STATE_SUBOBJECT_TYPE_NODE_MASK,
    D3D12_HEAP_FLAG_SHARED_CROSS_ADAPTER,
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEINDIRECT, D3D12_MEMORY_POOL_L1,
    DXGI_FORMAT_BC7_UNORM, D3D12_AUTO_BREADCRUMB_NODE1,
    D3D12_SRV_DIMENSION_TEXTURE2DMS,
    DXGI_FORMAT_R16G16B16A16_TYPELESS,
    D3D12_ROOT_SIGNATURE_FLAG_DENY_AMPLIFICATION_SHADER_ROOT_ACCESS,
    D3D12_RAYTRACING_GEOMETRY_TRIANGLES_DESC,
    D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT1, DXGI_FORMAT_R8_UINT,
    ID3D12DeviceRemovedExtendedData,
    D3D12_AUTO_BREADCRUMB_OP_EMITRAYTRACINGACCELERATIONSTRUCTUREPOSTBUILDINFO,
    D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ,
    D3D_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST, ID3D12Tools,
    D3D12_PROTECTED_SESSION_STATUS_OK,
    D3D12_VERSIONED_ROOT_SIGNATURE_DESC,
    DXGI_FORMAT_R10G10B10A2_UNORM, D3D12_VERTEX_BUFFER_VIEW,
    D3D12_HEAP_FLAG_CREATE_NOT_ZEROED, D3D12_TEX2D_UAV,
    DXGI_FORMAT_BC1_TYPELESS, D3D12_FEATURE_D3D12_OPTIONS6,
    D3D12_FEATURE_D3D12_OPTIONS4, D3D12_DISCARD_REGION,
    D3D12_SHADER_VISIBILITY_GEOMETRY, D3D12_TEX2DMS_RTV,
    D3D12_INPUT_CLASSIFICATION_PER_INSTANCE_DATA,
    DXGI_FORMAT_R16G16_UINT,
    D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_VOLATILE,
    D3D12_QUERY_HEAP_TYPE_TIMESTAMP, D3D12_LOGIC_OP_COPY,
    D3D12_FEATURE_SHADER_MODEL, D3D12_SHADER_VISIBILITY_DOMAIN,
    D3D11_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST,
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_GENERIC_READ,
    D3D12_FILTER_MINIMUM_MIN_MAG_MIP_POINT,
    D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME2, D3D12_RESOLVE_MODE_AVERAGE,
    D3D12_FILTER_MIN_MAG_LINEAR_MIP_POINT,
    D3D12_HEAP_FLAG_ALLOW_ONLY_RT_DS_TEXTURES,
    D3D12_AUTO_BREADCRUMB_OP_CLEARUNORDEREDACCESSVIEW,
    D3D_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST,
    D3D12_META_COMMAND_PARAMETER_TYPE_FLOAT,
    D3D12_AUTO_BREADCRUMB_OP_RESOLVEMOTIONVECTORHEAP,
    D3D_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST,
    D3D12_BARRIER_LAYOUT_VIDEO_DECODE_READ,
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP, D3D12_LOGIC_OP_NAND,
    D3D12_BLEND_OP_REV_SUBTRACT, D3D12_FEATURE_D3D12_OPTIONS20,
    D3D12_LOGIC_OP_CLEAR, D3D12_SHADER_VISIBILITY_ALL,
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ,
    D3D12_QUERY_TYPE_SO_STATISTICS_STREAM2,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_MINIMIZE_MEMORY,
    DXGI_FORMAT_BC5_TYPELESS, D3D12_RESIDENCY_PRIORITY_MINIMUM,
    D3D12_FEATURE_COMMAND_QUEUE_PRIORITY,
    D3D12_CONSTANT_BUFFER_VIEW_DESC, D3D12_ROOT_PARAMETER_TYPE_CBV,
    D3D12_BARRIER_LAYOUT_RESOLVE_SOURCE,
    D3D12_GRAPHICS_STATE_VIEW_INSTANCE_MASK,
    D3D12_UAV_DIMENSION_TEXTURE2DARRAY,
    D3D12_HEAP_FLAG_ALLOW_WRITE_WATCH, D3D12_SRV_DIMENSION_BUFFER,
    D3D12_META_COMMAND_PARAMETER_DESC,
    D3D12_ROOT_DESCRIPTOR_FLAG_NONE,
    D3D12_DRED_ALLOCATION_TYPE_PIPELINE_STATE, DXGI_FORMAT_Y416,
    DXGI_FORMAT_BC5_UNORM,
    D3D12_AUTO_BREADCRUMB_OP_CLEARRENDERTARGETVIEW,
    D3D12_RAYTRACING_GEOMETRY_TYPE_PROCEDURAL_PRIMITIVE_AABBS,
    D3D12_FEATURE_D3D12_OPTIONS, D3D12_DESCRIPTOR_RANGE1,
    D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_MIP_POINT, DXGI_FORMAT_NV12,
    D3D12_TILE_COPY_FLAG_NO_HAZARD,
    D3D12_GRAPHICS_STATE_GRAPHICS_ROOT_SIGNATURE,
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP, D3D12_FILTER_ANISOTROPIC,
    D3D_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST,
    D3D12_CULL_MODE_BACK, D3D12_DRED_BREADCRUMB_CONTEXT,
    D3D12_SHADER_CACHE_CONTROL_FLAG_ENABLE, DXGI_FORMAT_R8_UNORM,
    D3D12_BARRIER_LAYOUT_UNDEFINED, D3D12_RESIDENCY_PRIORITY_NORMAL,
    D3D12_RESOURCE_ALLOCATION_INFO1,
    D3D12_SHADER_CACHE_FLAG_USE_WORKING_DIR,
    D3D12_BARRIER_LAYOUT_RENDER_TARGET,
    D3D11_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST,
    D3D11_PRIMITIVE_TOPOLOGY_UNDEFINED,
    D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_INPUTS,
    D3D12_AUTO_BREADCRUMB_OP_ENCODEFRAME,
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_LINE, DXGI_FORMAT_BC2_UNORM_SRGB,
    D3D12_COMMAND_LIST_TYPE_VIDEO_ENCODE, DXGI_FORMAT_BC3_TYPELESS,
    DXGI_FORMAT_R32_FLOAT_X8X24_TYPELESS,
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_UNORDERED_ACCESS,
    D3D11_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST,
    D3D12_ROOT_SIGNATURE_FLAG_LOCAL_ROOT_SIGNATURE,
    D3D12_DEPTH_STENCILOP_DESC,
    D3D_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST,
    D3D12_FEATURE_FORMAT_INFO, D3D12_RESOURCE_DIMENSION_TEXTURE2D,
    DXGI_FORMAT_R32G32_UINT,
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_DEST,
    DXGI_FORMAT_R16G16B16A16_SINT,
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COMMON,
    D3D12_UAV_DIMENSION_TEXTURE1D, D3D12_COMMAND_QUEUE_FLAG_NONE,
    D3D12_LOGIC_OP_OR_REVERSE, DXGI_FORMAT_UNKNOWN,
    D3D12_GRAPHICS_STATE_OM_BLEND_FACTOR,
    D3D12_RESIDENCY_PRIORITY_MAXIMUM, DXGI_FORMAT_FORCE_UINT,
    D3D12_HEAP_FLAG_ALLOW_DISPLAY,
    D3D12_RESOURCE_STATE_SHADING_RATE_SOURCE,
    D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPES,
    DXGI_FORMAT_R32G32B32A32_SINT,
    D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_SHADER_CONFIG,
    D3D12_PLACED_SUBRESOURCE_FOOTPRINT, ID3D12DescriptorHeap,
    D3D12_BUFFER_UAV_FLAG_NONE, ID3D12Device10,
    D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_VERSION,
    DXGI_FORMAT_D32_FLOAT_S8X24_UINT, ID3D12MetaCommand,
    D3D12_DESCRIPTOR_RANGE_FLAG_NONE,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_PREBUILD_INFO,
    D3D12_QUERY_TYPE_TIMESTAMP, D3D_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ,
    D3D12_RESOLVE_MODE_DECODE_SAMPLER_FEEDBACK,
    D3D12_ROOT_SIGNATURE_FLAG_NONE,
    D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME1,
    D3D12_ELEMENTS_LAYOUT_ARRAY, DXGI_FORMAT_YUY2,
    D3D12_FEATURE_D3D12_OPTIONS3, D3D12_DRED_ENABLEMENT_FORCED_ON,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER,
    D3D12_RESOURCE_FLAG_DENY_SHADER_RESOURCE,
    D3D12_STREAM_OUTPUT_DESC, D3D12_AUTO_BREADCRUMB_OP_DISPATCHMESH,
    D3D12_TEX3D_SRV, D3D12_GRAPHICS_STATE_PIPELINE_STATE,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER_HEAP,
    D3D12_TILE_RANGE_FLAG_SKIP,
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_TRIANGLE, D3D12_TEX1D_ARRAY_RTV,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_PROCESSOR,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER_HEAP,
    D3D12_GRAPHICS_STATE_OM_STENCIL_REF,
    D3D12_DEPTH_STENCIL_VIEW_DESC,
    __MIDL___MIDL_itf_d3d12_0000_0003_0004, DXGI_FORMAT_R16G16_SINT,
    D3D12_AUTO_BREADCRUMB_OP_BUILDRAYTRACINGACCELERATIONSTRUCTURE,
    D3D12_LOGIC_OP_NOR, D3D12_PROTECTED_RESOURCE_SESSION_DESC1,
    D3D12_SHADING_RATE_4X4, DXGI_FORMAT_R10G10B10A2_UINT,
    D3D12_INDIRECT_ARGUMENT_DESC, D3D12_TEX2DMS_SRV,
    D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_MESH, ID3D12Device7,
    DXGI_FORMAT_R32_SINT, ID3D12GraphicsCommandList3,
    D3D12_PROTECTED_RESOURCE_SESSION_FLAG_NONE,
    D3D12_CPU_PAGE_PROPERTY_NOT_AVAILABLE,
    D3D12_AUTO_BREADCRUMB_OP_COPYRESOURCE, ID3D12PipelineLibrary,
    D3D12_BLEND_OP_SUBTRACT, D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSION,
    ID3D12LifetimeOwner, D3D12_SRV_DIMENSION_TEXTURE1DARRAY,
    D3D12_META_COMMAND_PARAMETER_STAGE_INITIALIZATION,
    D3D12_TEXTURE_LAYOUT_ROW_MAJOR, D3D12_STENCIL_OP_KEEP,
    D3D11_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST,
    D3D12_RESOURCE_STATE_STREAM_OUT, D3D12_COMMAND_QUEUE_DESC,
    ID3D12Device6, D3D12_LOGIC_OP_INVERT,
    D3D12_AUTO_BREADCRUMB_OP_RESOLVEENCODEROUTPUTMETADATA,
    D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT,
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ,
    D3D12_QUERY_HEAP_TYPE_COPY_QUEUE_TIMESTAMP, D3D12_RANGE_UINT64,
    DXGI_FORMAT_R8_TYPELESS,
    D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT_BUFFER_VIEW,
    D3D12_DRED_ENABLEMENT_SYSTEM_CONTROLLED,
    D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC,
    D3D12_ELEMENTS_LAYOUT_ARRAY_OF_POINTERS,
    D3D_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST,
    DXGI_FORMAT_R32_FLOAT, DXGI_FORMAT_B5G5R5A1_UNORM,
    D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_DESC,
    D3D12_ROOT_PARAMETER_TYPE_32BIT_CONSTANTS,
    D3D12_CPU_PAGE_PROPERTY_WRITE_BACK, ID3D12GraphicsCommandList4,
    D3D12_BUFFER_UAV, D3D12_DESCRIPTOR_HEAP_DESC,
    D3D12_CLEAR_FLAG_STENCIL, D3D12_FILTER_MIN_MAG_MIP_LINEAR,
    D3D12_BARRIER_LAYOUT_COMMON,
    D3D12_AUTO_BREADCRUMB_OP_BEGINSUBMISSION,
    D3D12_FILTER_MAXIMUM_ANISOTROPIC, D3D12_TEX2DMS_ARRAY_RTV,
    DXGI_FORMAT_R16G16_TYPELESS, D3D12_BARRIER_LAYOUT_PRESENT,
    D3D12_RESOURCE_BARRIER_FLAG_BEGIN_ONLY, D3D12_ROOT_DESCRIPTOR1,
    __MIDL___MIDL_itf_d3d12_0000_0003_0001, D3D12_SHADING_RATE_1X1,
    D3D12_RAYTRACING_GEOMETRY_AABBS_DESC,
    D3D12_QUERY_HEAP_TYPE_SO_STATISTICS,
    D3D11_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST,
    D3D12_PACKED_MIP_INFO,
    D3D_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_CURRENT_SIZE,
    DXGI_FORMAT_R32G8X24_TYPELESS, D3D10_PRIMITIVE_TOPOLOGY_LINELIST,
    DXGI_FORMAT_R8G8B8A8_TYPELESS,
    D3D12_ROOT_SIGNATURE_FLAG_CBV_SRV_UAV_HEAP_DIRECTLY_INDEXED,
    ID3D12CommandList, D3D12_HEAP_PROPERTIES, DXGI_SAMPLE_DESC,
    D3D12_DESCRIPTOR_RANGE_TYPE_SAMPLER, D3D12_BLEND_INV_DEST_COLOR,
    DXGI_FORMAT_R16G16B16A16_SNORM, D3D12_DESCRIPTOR_HEAP_TYPE_RTV,
    D3D12_RENDER_PASS_DEPTH_STENCIL_DESC,
    D3D12_DSV_DIMENSION_TEXTURE2DARRAY,
    D3D12_ROOT_DESCRIPTOR_FLAG_DATA_VOLATILE,
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ,
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_DISCARD,
    D3D12_AUTO_BREADCRUMB_OP_INITIALIZEMETACOMMAND,
    D3D12_ROOT_CONSTANTS,
    D3D12_SRV_DIMENSION_RAYTRACING_ACCELERATION_STRUCTURE,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_VECTOR_HEAP,
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_LIST,
    D3D12_DRED_ALLOCATION_TYPE_DESCRIPTOR_HEAP,
    D3D12_RESIDENCY_FLAG_NONE, D3D12_TEX2D_RTV, D3D12_ROOT_PARAMETER,
    D3D12_FILTER_COMPARISON_MIN_POINT_MAG_LINEAR_MIP_POINT,
    ID3D12ProtectedResourceSession, D3D12_INDEX_BUFFER_VIEW,
    D3D12_STATE_SUBOBJECT_TYPE_STATE_OBJECT_CONFIG,
    D3D12_COMPARISON_FUNC_NOT_EQUAL, DXGI_FORMAT_R8G8_SINT,
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_PRESERVE,
    D3D12_HEAP_FLAG_ALLOW_ALL_BUFFERS_AND_TEXTURES,
    D3D12_ROOT_SIGNATURE_FLAG_DENY_PIXEL_SHADER_ROOT_ACCESS,
    DXGI_FORMAT_SAMPLER_FEEDBACK_MIP_REGION_USED_OPAQUE,
    D3D12_GPU_VIRTUAL_ADDRESS_AND_STRIDE, D3D12_BLEND_BLEND_FACTOR,
    D3D12_QUERY_TYPE_VIDEO_DECODE_STATISTICS,
    D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CONVERSIONS,
    D3D12_RESOURCE_STATE_VIDEO_ENCODE_READ,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TOOLS_VISUALIZATION,
    D3D12_STATIC_BORDER_COLOR_OPAQUE_BLACK,
    D3D12_SHADING_RATE_COMBINER_MAX, DXGI_FORMAT_B8G8R8X8_UNORM,
    D3D12_RESOURCE_UAV_BARRIER, D3D12_FEATURE_D3D12_OPTIONS8,
    DXGI_FORMAT_R8G8B8A8_SNORM, D3D12_SRV_DIMENSION_UNKNOWN,
    D3D12_RESOURCE_DIMENSION_TEXTURE1D, ID3D12ShaderCacheSession,
    D3D12_RENDER_PASS_FLAG_RESUMING_PASS,
    D3D12_FILTER_MINIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT,
    D3D_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST,
    D3D12_BARRIER_LAYOUT_UNORDERED_ACCESS,
    ID3D12DeviceRemovedExtendedData1,
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_UNORDERED_ACCESS,
    DXGI_FORMAT_A8P8, D3D12_FILTER_COMPARISON_MIN_MAG_MIP_POINT,
    D3D12_CULL_MODE_FRONT, D3D12_ROOT_PARAMETER_TYPE_SRV,
    D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_MIP_POINT,
    D3D12_DESCRIPTOR_HEAP_TYPE_SAMPLER, DXGI_FORMAT_V208,
    D3D12_MULTIPLE_FENCE_WAIT_FLAG_ANY, D3D12_BLEND_ALPHA_FACTOR,
    D3D_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST, DXGI_FORMAT_P8,
    ID3D12GraphicsCommandList1,
    D3D12_TEXTURE_COPY_TYPE_SUBRESOURCE_INDEX,
    D3D12_TEXTURE_COPY_TYPE_PLACED_FOOTPRINT,
    DXGI_FORMAT_R9G9B9E5_SHAREDEXP, D3D12_TEXTURE_ADDRESS_MODE_MIRROR,
    D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_TYPE,
    D3D12_MULTIPLE_FENCE_WAIT_FLAG_ALL, DXGI_FORMAT_R32_TYPELESS,
    D3D12_DRED_ALLOCATION_NODE1, DXGI_FORMAT_R1_UNORM,
    D3D12_STENCIL_OP_DECR_SAT, D3D12_BLEND_INV_SRC_ALPHA,
    D3D11_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST,
    D3D12_GRAPHICS_STATE_SAMPLE_POSITIONS,
    D3D12_FILTER_MINIMUM_MIN_MAG_POINT_MIP_LINEAR,
    D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCE,
    D3D12_RESOURCE_TRANSITION_BARRIER,
    D3D12_RESOURCE_STATE_DEPTH_WRITE,
    D3D_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST,
    D3D12_COMPARISON_FUNC_GREATER_EQUAL, D3D12_TEX1D_DSV,
    D3D12_DRED_ALLOCATION_NODE, D3D12_LOGIC_OP_AND_REVERSE,
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_SOURCE, D3D12_TEX2D_DSV,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_SERIALIZE,
    DXGI_FORMAT_R16_TYPELESS, DXGI_FORMAT_R32G32_SINT,
    D3D12_ROOT_PARAMETER_TYPE_UAV, ID3D12Device9,
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER,
    D3D12_DESCRIPTOR_RANGE_TYPE_SRV,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_TOP_LEVEL,
    __MIDL___MIDL_itf_d3d12_0000_0001_0002,
    D3D12_QUERY_HEAP_TYPE_OCCLUSION,
    D3D12_INDIRECT_ARGUMENT_TYPE_VERTEX_BUFFER_VIEW,
    DXGI_FORMAT_R16G16_UNORM, DXGI_FORMAT_AYUV,
    D3D12_GRAPHICS_STATE_RS_VIEWPORTS, D3D12_FEATURE_D3D12_OPTIONS5,
    D3D12_ROOT_SIGNATURE_DESC1, Library, DXGI_FORMAT_G8R8_G8B8_UNORM,
    D3D12_FENCE_FLAG_SHARED_CROSS_ADAPTER,
    D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CACHE_FOR_DRIVER,
    D3D12_TEXTURE_ADDRESS_MODE_MIRROR_ONCE,
    D3D12_TEXTURE_ADDRESS_MODE_WRAP, D3D12_GPU_VIRTUAL_ADDRESS_RANGE,
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_SHADER_RESOURCE,
    D3D12_SHADER_CACHE_FLAG_DRIVER_VERSIONED, D3D12_STENCIL_OP_ZERO,
    D3D12_FEATURE_SHADER_CACHE, DXGI_FORMAT_BC2_UNORM,
    DXGI_FORMAT_IA44,
    D3D12_DRED_ALLOCATION_TYPE_PROTECTEDRESOURCESESSION,
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_SHADER_RESOURCE,
    D3D_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST,
    D3D12_DSV_DIMENSION_TEXTURE2D,
    D3D12_PREDICATION_OP_NOT_EQUAL_ZERO, D3D12_STATE_OBJECT_DESC,
    D3D12_TEXTURE_COPY_LOCATION, D3D12_SRV_DIMENSION_TEXTURE2DARRAY,
    DXGI_FORMAT_B8G8R8X8_TYPELESS, D3D12_RESOLVE_MODE_MIN,
    DXGI_FORMAT_BC6H_TYPELESS, D3D12_RENDER_PASS_RENDER_TARGET_DESC,
    __MIDL___MIDL_itf_d3d12_0000_0001_0006, D3D12_RESOURCE_FLAG_NONE,
    D3D12_DRED_ALLOCATION_TYPE_PIPELINE_LIBRARY,
    D3D12_DRED_ALLOCATION_TYPE_SCHEDULINGGROUP,
    D3D12_PROTECTED_RESOURCE_SESSION_DESC,
    D3D12_FEATURE_D3D12_OPTIONS12,
    D3D12_FILTER_COMPARISON_MIN_MAG_MIP_LINEAR,
    D3D12_RESOURCE_FLAG_ALLOW_UNORDERED_ACCESS,
    D3D12_COMMAND_LIST_TYPE_DIRECT, D3D12_FEATURE_D3D12_OPTIONS10,
    D3D12_DESCRIPTOR_RANGE_FLAG_DATA_VOLATILE,
    D3D12_AUTO_BREADCRUMB_OP_PRESENT,
    D3D12_GRAPHICS_STATE_IA_PRIMITIVE_TOPOLOGY,
    D3D12_FILTER_COMPARISON_MIN_MAG_POINT_MIP_LINEAR,
    DXGI_FORMAT_AI44,
    D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_POINT_MIP_LINEAR,
    D3D12_RAYTRACING_GEOMETRY_FLAG_NONE,
    D3D12_DSV_DIMENSION_TEXTURE1D,
    D3D12_INPUT_CLASSIFICATION_PER_VERTEX_DATA,
    D3D12_BLEND_DEST_COLOR, D3D12_RTV_DIMENSION_TEXTURE2D,
    DXGI_FORMAT_R16_UNORM,
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_PRESERVE, IUnknown,
    D3D12_HEAP_FLAG_CREATE_NOT_RESIDENT, DXGI_FORMAT_R8G8B8A8_UNORM,
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_DEST,
    D3D12_BLEND_INV_SRC_COLOR,
    D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_MIP_POINT,
    D3D12_GRAPHICS_STATE_OM_DEPTH_BOUNDS,
    D3D11_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST,
    D3D12_TEX1D_ARRAY_DSV, D3D12_DRED_PAGE_FAULT_OUTPUT,
    D3D12_RENDER_PASS_FLAG_NONE,
    D3D12_GRAPHICS_STATE_RS_SCISSOR_RECTS, D3D12_FEATURE_ARCHITECTURE,
    D3D12_STATE_SUBOBJECT_TYPE_SUBOBJECT_TO_EXPORTS_ASSOCIATION,
    D3D12_DRED_ALLOCATION_TYPE_INVALID, D3D12_TEXTURE_LAYOUT_UNKNOWN,
    typelib_path, D3D12_TILE_RANGE_FLAG_NONE, DXGI_FORMAT_D16_UNORM,
    DXGI_FORMAT_R16_SNORM,
    D3D12_GRAPHICS_STATE_COMPUTE_ROOT_SIGNATURE,
    D3D12_SHADER_CACHE_MODE_DISK,
    ID3D12DeviceRemovedExtendedDataSettings, ID3D12RootSignature,
    D3D12_RTV_DIMENSION_TEXTURE2DARRAY,
    D3D12_RENDER_PASS_FLAG_SUSPENDING_PASS, ID3D12QueryHeap,
    D3D12_RESOLVE_MODE_ENCODE_SAMPLER_FEEDBACK, D3D12_TEX2DMS_DSV,
    D3D11_PRIMITIVE_TOPOLOGY_LINELIST_ADJ,
    D3D11_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST,
    D3D12_TILE_COPY_FLAG_NONE,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_NONE,
    D3D12_BARRIER_LAYOUT_SHADER_RESOURCE,
    __MIDL___MIDL_itf_d3d12_0000_0001_0010,
    D3D12_AUTO_BREADCRUMB_OP_DRAWINSTANCED,
    D3D_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST,
    D3D12_SERIALIZED_DATA_DRIVER_MATCHING_IDENTIFIER,
    DXGI_FORMAT_R8G8B8A8_SINT, D3D12_HEAP_FLAG_HARDWARE_PROTECTED,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_TRACE,
    D3D12_COMMAND_LIST_TYPE_COPY,
    D3D12_FILTER_MINIMUM_MIN_MAG_LINEAR_MIP_POINT, D3D12_TEX3D_UAV,
    D3D12_RESOURCE_STATE_PIXEL_SHADER_RESOURCE, DXGI_FORMAT_D32_FLOAT,
    D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_SUPPORT,
    DXGI_FORMAT_BC3_UNORM, D3D12_TEX2D_ARRAY_DSV,
    DXGI_FORMAT_B5G6R5_UNORM, DXGI_FORMAT_P208,
    D3D12_RESOURCE_STATE_PRESENT,
    D3D12_WRITEBUFFERIMMEDIATE_MODE_DEFAULT, GUID,
    D3D12_RESOURCE_STATE_RAYTRACING_ACCELERATION_STRUCTURE,
    D3D12_TEX2DMS_ARRAY_SRV, D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC,
    D3D12_SHADING_RATE_COMBINER_MIN, D3D12_SAMPLE_POSITION,
    D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS, D3D12_FENCE_FLAG_NONE,
    ID3D12Device5,
    D3D11_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST,
    DXGI_FORMAT_A8_UNORM, D3D12_META_COMMAND_PARAMETER_FLAG_INPUT,
    D3D12_UNORDERED_ACCESS_VIEW_DESC, D3D12_BLEND_DESC,
    D3D12_GPU_VIRTUAL_ADDRESS_RANGE_AND_STRIDE,
    D3D12_RESOURCE_FLAG_RAYTRACING_ACCELERATION_STRUCTURE,
    D3D12_RESOURCE_STATE_COPY_SOURCE,
    DXGI_FORMAT_X32_TYPELESS_G8X24_UINT,
    D3D11_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST,
    D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFFFFFF,
    ID3D12PipelineLibrary1,
    D3D12_RESOURCE_STATE_NON_PIXEL_SHADER_RESOURCE,
    D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_WRITE,
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST, D3D12_BUFFER_SRV,
    D3D12_DESCRIPTOR_HEAP_FLAG_SHADER_VISIBLE,
    D3D12_FILTER_MIN_POINT_MAG_LINEAR_MIP_POINT,
    D3D_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST,
    D3D12_RAYTRACING_GEOMETRY_FLAG_OPAQUE, ID3D12CommandQueue,
    D3D12_DEPTH_STENCIL_VALUE,
    D3D12_BARRIER_LAYOUT_VIDEO_DECODE_WRITE,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_COMPACTED_SIZE,
    D3D12_GRAPHICS_STATE_DESCRIPTOR_HEAP,
    D3D12_FILTER_MIN_LINEAR_MAG_POINT_MIP_LINEAR,
    D3D12_GRAPHICS_STATE_IA_INDEX_BUFFER,
    D3D12_SRV_DIMENSION_TEXTURECUBEARRAY,
    __MIDL___MIDL_itf_d3d12_0000_0034_0001,
    D3D12_BARRIER_LAYOUT_COPY_SOURCE, ID3D12StateObject,
    D3D12_TEXTURE_ADDRESS_MODE_CLAMP, DXGI_FORMAT_R16G16B16A16_UNORM,
    D3D12_RESOURCE_STATE_COPY_DEST, ID3D12StateObjectProperties,
    ID3D12Pageable, D3D12_DISPATCH_RAYS_DESC,
    D3D12_DRED_ALLOCATION_TYPE_HEAP,
    D3D12_RESOURCE_DIMENSION_TEXTURE3D,
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_PATCH,
    D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_OUT,
    D3D11_PRIMITIVE_TOPOLOGY_LINELIST, D3D12_DEPTH_WRITE_MASK_ZERO,
    DXGI_FORMAT_R32G32B32A32_UINT,
    D3D12_AUTO_BREADCRUMB_OP_COPYBUFFERREGION,
    D3D12_RESOURCE_DIMENSION_BUFFER, DXGI_FORMAT_R32G32B32_UINT,
    D3D12_RESOURCE_STATE_DEPTH_READ,
    D3D12_AUTO_BREADCRUMB_OP_ESTIMATEMOTION, D3D12_INPUT_ELEMENT_DESC,
    D3D12_QUERY_TYPE_SO_STATISTICS_STREAM0,
    D3D12_SRV_DIMENSION_TEXTURE2D,
    D3D12_DSV_DIMENSION_TEXTURE2DMSARRAY,
    D3D12_STATE_SUBOBJECT_TYPE_EXISTING_COLLECTION,
    D3D12_RESOURCE_STATE_RESOLVE_DEST,
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_CLEAR,
    D3D12_COMMAND_QUEUE_FLAG_DISABLE_GPU_TIMEOUT,
    D3D12_CPU_DESCRIPTOR_HANDLE,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_SRV,
    D3D12_AUTO_BREADCRUMB_OP_SETPROTECTEDRESOURCESESSION,
    D3D12_COMPUTE_PIPELINE_STATE_DESC,
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ,
    D3D12_COMPARISON_FUNC_LESS_EQUAL,
    D3D12_TILE_COPY_FLAG_LINEAR_BUFFER_TO_SWIZZLED_TILED_RESOURCE,
    D3D12_SHADER_VISIBILITY_HULL,
    D3D12_DRED_ALLOCATION_TYPE_METACOMMAND,
    D3D12_STATE_SUBOBJECT_TYPE_HIT_GROUP,
    D3D_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST,
    D3D_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST,
    DXGI_FORMAT_D24_UNORM_S8_UINT,
    D3D12_AUTO_BREADCRUMB_OP_DISPATCHRAYS,
    D3D12_ROOT_SIGNATURE_FLAG_DENY_DOMAIN_SHADER_ROOT_ACCESS,
    D3D12_BLEND_SRC_ALPHA_SAT,
    D3D12_FEATURE_GPU_VIRTUAL_ADDRESS_SUPPORT,
    ID3D12VersionedRootSignatureDeserializer,
    D3D12_ROOT_SIGNATURE_DESC, D3D12_STENCIL_OP_INCR_SAT,
    D3D11_PRIMITIVE_TOPOLOGY_POINTLIST, D3D12_SHADER_BYTECODE,
    ID3D12CommandSignature, D3D12_RESOURCE_STATE_GENERIC_READ,
    D3D12_RESOLVE_MODE_DECOMPRESS, D3D12_SUBRESOURCE_TILING,
    D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_RAYS,
    D3D12_SHADER_CACHE_KIND_FLAG_APPLICATION_MANAGED,
    D3D12_SHADER_VISIBILITY_AMPLIFICATION,
    D3D12_RTV_DIMENSION_TEXTURE1D, D3D12_SHADER_CACHE_FLAG_NONE,
    __MIDL___MIDL_itf_d3d12_0000_0001_0007,
    D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_READ,
    D3D12_RESIDENCY_PRIORITY_LOW, ID3D12Device4,
    D3D12_ROOT_SIGNATURE_FLAG_DENY_VERTEX_SHADER_ROOT_ACCESS,
    D3D12_AUTO_BREADCRUMB_OP_COPYTEXTUREREGION, DXGI_FORMAT_BC4_SNORM,
    D3D12_BACKGROUND_PROCESSING_MODE_ALLOWED,
    D3D12_MEASUREMENTS_ACTION_KEEP_ALL, D3D12_COMMAND_LIST_FLAG_NONE,
    D3D12_COMMAND_LIST_TYPE_BUNDLE, D3D12_PIPELINE_STATE_STREAM_DESC,
    D3D12_RESIDENCY_PRIORITY_HIGH, D3D12_TILE_RANGE_FLAG_NULL,
    D3D12_SHADING_RATE_COMBINER_PASSTHROUGH, D3D12_TEXCUBE_ARRAY_SRV,
    ID3D12Object, D3D12_RESOURCE_STATE_UNORDERED_ACCESS,
    D3D12_DRED_ENABLEMENT_FORCED_OFF,
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP, D3D12_FEATURE_DISPLAYABLE,
    D3D_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST,
    D3D12_RAYTRACING_GEOMETRY_FLAG_NO_DUPLICATE_ANYHIT_INVOCATION,
    D3D12_QUERY_HEAP_DESC,
    D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG1,
    DXGI_FORMAT_R32G32B32_SINT, D3D12_LOGIC_OP_NOOP,
    D3D_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST,
    D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPE_COUNT,
    D3D12_AUTO_BREADCRUMB_NODE,
    __MIDL___MIDL_itf_d3d12_0000_0003_0003,
    D3D12_SHADER_RESOURCE_VIEW_DESC,
    D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_SERIALIZATION,
    D3D12_DEPTH_WRITE_MASK_ALL, D3D12_FEATURE_D3D12_OPTIONS13,
    D3D12_BLEND_DEST_ALPHA, D3D12_RESOURCE_STATE_VIDEO_PROCESS_READ,
    D3D12_HEAP_FLAG_DENY_BUFFERS, D3D12_TILED_RESOURCE_COORDINATE,
    D3D11_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST,
    D3D12_BLEND_SRC_ALPHA, D3D12_PREDICATION_OP_EQUAL_ZERO,
    D3D12_DSV_DIMENSION_UNKNOWN, D3D12_PIPELINE_STATE_FLAG_NONE,
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST,
    D3D12_RESOURCE_ALIASING_BARRIER, D3D12_DESCRIPTOR_HEAP_TYPE_DSV,
    __MIDL___MIDL_itf_d3d12_0000_0048_0002, D3D12_BLEND_OP_MIN,
    D3D12_QUERY_HEAP_TYPE_VIDEO_DECODE_STATISTICS,
    D3D12_FEATURE_EXISTING_HEAPS,
    D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSIONPOLICY,
    D3D12_SUBRESOURCE_FOOTPRINT,
    D3D12_RESOURCE_FLAG_ALLOW_DEPTH_STENCIL,
    D3D12_RESOURCE_BARRIER_FLAG_NONE,
    D3D12_GRAPHICS_STATE_OM_RENDER_TARGETS, D3D12_STENCIL_OP_REPLACE,
    D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_MIP_LINEAR,
    D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_PROFILING_BY_SYSTEM,
    D3D12_CULL_MODE_NONE, D3D12_MULTIPLE_FENCE_WAIT_FLAG_NONE,
    ID3D12GraphicsCommandList2, DXGI_FORMAT_Y410, DXGI_FORMAT_NV11,
    D3D12_RESOURCE_STATE_RESOLVE_SOURCE, ID3D10Blob,
    D3D12_TEXTURE_LAYOUT_64KB_STANDARD_SWIZZLE,
    D3D12_SHADING_RATE_4X2, D3D12_FENCE_FLAG_SHARED,
    D3D12_UAV_DIMENSION_UNKNOWN,
    D3D12_ROOT_SIGNATURE_FLAG_DENY_HULL_SHADER_ROOT_ACCESS,
    D3D12_RENDER_TARGET_VIEW_DESC, D3D12_DESCRIPTOR_RANGE_TYPE_CBV,
    D3D12_SRV_DIMENSION_TEXTURE2DMSARRAY,
    D3D12_GRAPHICS_PIPELINE_STATE_DESC,
    D3D12_BARRIER_LAYOUT_RESOLVE_DEST,
    D3D12_MEASUREMENTS_ACTION_DISCARD_PREVIOUS,
    D3D12_BLEND_INV_SRC1_COLOR, D3D12_UAV_DIMENSION_TEXTURE2D,
    DXGI_FORMAT_BC6H_SF16,
    D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR,
    D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_IN,
    D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_READ,
    D3D11_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST,
    D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP, D3D12_SRV_DIMENSION_TEXTURE1D,
    D3D12_RESOURCE_STATE_INDIRECT_ARGUMENT,
    D3D11_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST,
    D3D12_RAYTRACING_GEOMETRY_DESC,
    D3D_PRIMITIVE_TOPOLOGY_LINELIST_ADJ,
    __MIDL___MIDL_itf_d3d12_0000_0001_0003, D3D12_TEX1D_ARRAY_SRV,
    D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_WRITE,
    D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_DRIVER_MANAGED,
    D3D12_BACKGROUND_PROCESSING_MODE_ALLOW_INTRUSIVE_MEASUREMENTS,
    D3D12_FILTER_MIN_LINEAR_MAG_MIP_POINT, D3D12_LOGIC_OP_AND,
    D3D12_STATE_SUBOBJECT, DXGI_FORMAT_R32G32_FLOAT,
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_UNDEFINED,
    D3D12_HEAP_FLAG_ALLOW_ONLY_BUFFERS, D3D12_INPUT_LAYOUT_DESC,
    D3D12_LOGIC_OP_XOR, ID3D12Device, D3D12_SO_DECLARATION_ENTRY,
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_POOL,
    DXGI_FORMAT_R8G8B8A8_UNORM_SRGB, D3D_PRIMITIVE_TOPOLOGY_UNDEFINED,
    D3D12_STENCIL_OP_INCR, DXGI_FORMAT_B4G4R4A4_UNORM,
    __MIDL___MIDL_itf_d3d12_0000_0001_0001,
    D3D12_FEATURE_D3D12_OPTIONS2, DXGI_FORMAT_BC1_UNORM_SRGB,
    D3D12_ROOT_PARAMETER1, D3D12_DESCRIPTOR_RANGE,
    DXGI_FORMAT_R16_SINT, DXGI_FORMAT_420_OPAQUE,
    D3D12_META_COMMAND_PARAMETER_STAGE_CREATION,
    D3D12_GRAPHICS_STATE_IA_VERTEX_BUFFERS, DXGI_FORMAT_BC7_TYPELESS,
    D3D12_TEX2D_ARRAY_SRV, D3D12_SHADING_RATE_COMBINER_OVERRIDE,
    D3D12_ROOT_PARAMETER_TYPE_DESCRIPTOR_TABLE, D3D12_BLEND_OP_ADD,
    D3D12_CLEAR_FLAG_DEPTH,
    D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS_HIGH_PRIORITY,
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEMETACOMMAND,
    DXGI_FORMAT_B8G8R8A8_TYPELESS,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_BUILD,
    __LUID, D3D12_BARRIER_LAYOUT_COPY_DEST, _lcid, D3D12_MIP_REGION,
    D3D12_LIFETIME_STATE_IN_USE, D3D12_SRV_DIMENSION_TEXTURECUBE,
    D3D12_DSV_FLAG_NONE,
    D3D11_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST,
    D3D12_RTV_DIMENSION_TEXTURE2DMSARRAY,
    D3D12_TEXTURE_LAYOUT_64KB_UNDEFINED_SWIZZLE,
    D3D10_PRIMITIVE_TOPOLOGY_LINELIST_ADJ,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_COMPACT,
    D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCEREGION,
    DXGI_FORMAT_SAMPLER_FEEDBACK_MIN_MIP_OPAQUE,
    D3D11_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST, ID3D12Fence,
    D3D12_DSV_DIMENSION_TEXTURE1DARRAY,
    D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_READ,
    D3D12_DRIVER_MATCHING_IDENTIFIER_UNRECOGNIZED,
    D3D_ROOT_SIGNATURE_VERSION_1_0, D3D_PRIMITIVE_TOPOLOGY_POINTLIST,
    D3D12_WRITEBUFFERIMMEDIATE_PARAMETER,
    D3D12_FEATURE_D3D12_OPTIONS11,
    D3D12_SERIALIZED_DATA_RAYTRACING_ACCELERATION_STRUCTURE,
    D3D12_AUTO_BREADCRUMB_OP_COPYRAYTRACINGACCELERATIONSTRUCTURE,
    D3D11_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PERFORM_UPDATE,
    DXGI_FORMAT_Y210, D3D12_STREAM_OUTPUT_BUFFER_VIEW,
    D3D12_DESCRIPTOR_RANGE_TYPE_UAV, ID3D12Resource,
    D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_DISABLED,
    D3D12_TEXTURE_ADDRESS_MODE_BORDER,
    D3D12_STATIC_BORDER_COLOR_TRANSPARENT_BLACK,
    D3D12_GRAPHICS_STATE_SO_TARGETS,
    D3D12_ROOT_SIGNATURE_FLAG_ALLOW_INPUT_ASSEMBLER_INPUT_LAYOUT,
    D3D12_ROOT_SIGNATURE_FLAG_SAMPLER_HEAP_DIRECTLY_INDEXED,
    D3D12_PIPELINE_STATE_FLAG_TOOL_DEBUG, D3D12_HEAP_TYPE_DEFAULT,
    D3D_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST,
    DXGI_FORMAT_R16G16_SNORM, D3D12_QUERY_TYPE_SO_STATISTICS_STREAM3,
    D3D12_RESOURCE_BARRIER_TYPE_UAV, D3D12_FEATURE_CROSS_NODE,
    D3D11_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST,
    D3D12_CLEAR_VALUE, D3D12_BARRIER_LAYOUT_GENERIC_READ,
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_NO_ACCESS,
    D3D11_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST,
    D3D11_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST,
    D3D12_RESOURCE_FLAG_VIDEO_ENCODE_REFERENCE_ONLY,
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_SOURCE,
    D3D12_RTV_DIMENSION_TEXTURE3D, DXGI_FORMAT_BC6H_UF16,
    D3D12_BLEND_SRC_COLOR,
    D3D12_RESOURCE_STATE_VERTEX_AND_CONSTANT_BUFFER,
    D3D12_FEATURE_D3D12_OPTIONS19,
    D3D12_META_COMMAND_PARAMETER_TYPE_CPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV,
    D3D11_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST,
    D3D12_DRIVER_MATCHING_IDENTIFIER_UNSUPPORTED_TYPE,
    __MIDL___MIDL_itf_d3d12_0000_0001_0004,
    __MIDL___MIDL_itf_d3d12_0000_0048_0001,
    D3D_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST,
    D3D12_COMPARISON_FUNC_LESS,
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_DESC,
    D3D12_SAMPLER_DESC, D3D_PRIMITIVE_TOPOLOGY_LINESTRIP,
    __MIDL___MIDL_itf_d3d12_0000_0001_0008,
    DXGI_FORMAT_R24G8_TYPELESS, D3D12_RTV_DIMENSION_TEXTURE2DMS,
    ID3D12PipelineState, D3D12_TEX1D_ARRAY_UAV,
    D3D12_DESCRIPTOR_HEAP_FLAG_NONE, D3D12_SHADING_RATE_COMBINER_SUM
)


class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE(IntFlag):
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_CLONE = 0
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_COMPACT = 1
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_VISUALIZATION_DECODE_FOR_TOOLS = 2
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_SERIALIZE = 3
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_DESERIALIZE = 4


class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE(IntFlag):
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_COMPACTED_SIZE = 0
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TOOLS_VISUALIZATION = 1
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_SERIALIZATION = 2
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_CURRENT_SIZE = 3


class D3D12_DESCRIPTOR_HEAP_FLAGS(IntFlag):
    D3D12_DESCRIPTOR_HEAP_FLAG_NONE = 0
    D3D12_DESCRIPTOR_HEAP_FLAG_SHADER_VISIBLE = 1


class D3D12_DESCRIPTOR_HEAP_TYPE(IntFlag):
    D3D12_DESCRIPTOR_HEAP_TYPE_CBV_SRV_UAV = 0
    D3D12_DESCRIPTOR_HEAP_TYPE_SAMPLER = 1
    D3D12_DESCRIPTOR_HEAP_TYPE_RTV = 2
    D3D12_DESCRIPTOR_HEAP_TYPE_DSV = 3
    D3D12_DESCRIPTOR_HEAP_TYPE_NUM_TYPES = 4


class D3D12_BLEND_OP(IntFlag):
    D3D12_BLEND_OP_ADD = 1
    D3D12_BLEND_OP_SUBTRACT = 2
    D3D12_BLEND_OP_REV_SUBTRACT = 3
    D3D12_BLEND_OP_MIN = 4
    D3D12_BLEND_OP_MAX = 5


class D3D12_HEAP_FLAGS(IntFlag):
    D3D12_HEAP_FLAG_NONE = 0
    D3D12_HEAP_FLAG_SHARED = 1
    D3D12_HEAP_FLAG_DENY_BUFFERS = 4
    D3D12_HEAP_FLAG_ALLOW_DISPLAY = 8
    D3D12_HEAP_FLAG_SHARED_CROSS_ADAPTER = 32
    D3D12_HEAP_FLAG_DENY_RT_DS_TEXTURES = 64
    D3D12_HEAP_FLAG_DENY_NON_RT_DS_TEXTURES = 128
    D3D12_HEAP_FLAG_HARDWARE_PROTECTED = 256
    D3D12_HEAP_FLAG_ALLOW_WRITE_WATCH = 512
    D3D12_HEAP_FLAG_ALLOW_SHADER_ATOMICS = 1024
    D3D12_HEAP_FLAG_CREATE_NOT_RESIDENT = 2048
    D3D12_HEAP_FLAG_CREATE_NOT_ZEROED = 4096
    D3D12_HEAP_FLAG_ALLOW_ALL_BUFFERS_AND_TEXTURES = 0
    D3D12_HEAP_FLAG_ALLOW_ONLY_BUFFERS = 192
    D3D12_HEAP_FLAG_ALLOW_ONLY_NON_RT_DS_TEXTURES = 68
    D3D12_HEAP_FLAG_ALLOW_ONLY_RT_DS_TEXTURES = 132


class D3D12_PROTECTED_SESSION_STATUS(IntFlag):
    D3D12_PROTECTED_SESSION_STATUS_OK = 0
    D3D12_PROTECTED_SESSION_STATUS_INVALID = 1


class D3D12_PROTECTED_RESOURCE_SESSION_FLAGS(IntFlag):
    D3D12_PROTECTED_RESOURCE_SESSION_FLAG_NONE = 0


class D3D12_LOGIC_OP(IntFlag):
    D3D12_LOGIC_OP_CLEAR = 0
    D3D12_LOGIC_OP_SET = 1
    D3D12_LOGIC_OP_COPY = 2
    D3D12_LOGIC_OP_COPY_INVERTED = 3
    D3D12_LOGIC_OP_NOOP = 4
    D3D12_LOGIC_OP_INVERT = 5
    D3D12_LOGIC_OP_AND = 6
    D3D12_LOGIC_OP_NAND = 7
    D3D12_LOGIC_OP_OR = 8
    D3D12_LOGIC_OP_NOR = 9
    D3D12_LOGIC_OP_XOR = 10
    D3D12_LOGIC_OP_EQUIV = 11
    D3D12_LOGIC_OP_AND_REVERSE = 12
    D3D12_LOGIC_OP_AND_INVERTED = 13
    D3D12_LOGIC_OP_OR_REVERSE = 14
    D3D12_LOGIC_OP_OR_INVERTED = 15


class D3D12_SHADING_RATE(IntFlag):
    D3D12_SHADING_RATE_1X1 = 0
    D3D12_SHADING_RATE_1X2 = 1
    D3D12_SHADING_RATE_2X1 = 4
    D3D12_SHADING_RATE_2X2 = 5
    D3D12_SHADING_RATE_2X4 = 6
    D3D12_SHADING_RATE_4X2 = 9
    D3D12_SHADING_RATE_4X4 = 10


class D3D12_SHADING_RATE_COMBINER(IntFlag):
    D3D12_SHADING_RATE_COMBINER_PASSTHROUGH = 0
    D3D12_SHADING_RATE_COMBINER_OVERRIDE = 1
    D3D12_SHADING_RATE_COMBINER_MIN = 2
    D3D12_SHADING_RATE_COMBINER_MAX = 3
    D3D12_SHADING_RATE_COMBINER_SUM = 4


class D3D12_TILE_RANGE_FLAGS(IntFlag):
    D3D12_TILE_RANGE_FLAG_NONE = 0
    D3D12_TILE_RANGE_FLAG_NULL = 1
    D3D12_TILE_RANGE_FLAG_SKIP = 2
    D3D12_TILE_RANGE_FLAG_REUSE_SINGLE_TILE = 4


class D3D12_COMMAND_LIST_TYPE(IntFlag):
    D3D12_COMMAND_LIST_TYPE_DIRECT = 0
    D3D12_COMMAND_LIST_TYPE_BUNDLE = 1
    D3D12_COMMAND_LIST_TYPE_COMPUTE = 2
    D3D12_COMMAND_LIST_TYPE_COPY = 3
    D3D12_COMMAND_LIST_TYPE_VIDEO_DECODE = 4
    D3D12_COMMAND_LIST_TYPE_VIDEO_PROCESS = 5
    D3D12_COMMAND_LIST_TYPE_VIDEO_ENCODE = 6


class D3D12_FEATURE(IntFlag):
    D3D12_FEATURE_D3D12_OPTIONS = 0
    D3D12_FEATURE_ARCHITECTURE = 1
    D3D12_FEATURE_FEATURE_LEVELS = 2
    D3D12_FEATURE_FORMAT_SUPPORT = 3
    D3D12_FEATURE_MULTISAMPLE_QUALITY_LEVELS = 4
    D3D12_FEATURE_FORMAT_INFO = 5
    D3D12_FEATURE_GPU_VIRTUAL_ADDRESS_SUPPORT = 6
    D3D12_FEATURE_SHADER_MODEL = 7
    D3D12_FEATURE_D3D12_OPTIONS1 = 8
    D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_SUPPORT = 10
    D3D12_FEATURE_ROOT_SIGNATURE = 12
    D3D12_FEATURE_ARCHITECTURE1 = 16
    D3D12_FEATURE_D3D12_OPTIONS2 = 18
    D3D12_FEATURE_SHADER_CACHE = 19
    D3D12_FEATURE_COMMAND_QUEUE_PRIORITY = 20
    D3D12_FEATURE_D3D12_OPTIONS3 = 21
    D3D12_FEATURE_EXISTING_HEAPS = 22
    D3D12_FEATURE_D3D12_OPTIONS4 = 23
    D3D12_FEATURE_SERIALIZATION = 24
    D3D12_FEATURE_CROSS_NODE = 25
    D3D12_FEATURE_D3D12_OPTIONS5 = 27
    D3D12_FEATURE_DISPLAYABLE = 28
    D3D12_FEATURE_D3D12_OPTIONS6 = 30
    D3D12_FEATURE_QUERY_META_COMMAND = 31
    D3D12_FEATURE_D3D12_OPTIONS7 = 32
    D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPE_COUNT = 33
    D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPES = 34
    D3D12_FEATURE_D3D12_OPTIONS8 = 36
    D3D12_FEATURE_D3D12_OPTIONS9 = 37
    D3D12_FEATURE_D3D12_OPTIONS10 = 39
    D3D12_FEATURE_D3D12_OPTIONS11 = 40
    D3D12_FEATURE_D3D12_OPTIONS12 = 41
    D3D12_FEATURE_D3D12_OPTIONS13 = 42
    D3D12_FEATURE_D3D12_OPTIONS19 = 48
    D3D12_FEATURE_D3D12_OPTIONS20 = 49


class D3D12_HEAP_TYPE(IntFlag):
    D3D12_HEAP_TYPE_DEFAULT = 1
    D3D12_HEAP_TYPE_UPLOAD = 2
    D3D12_HEAP_TYPE_READBACK = 3
    D3D12_HEAP_TYPE_CUSTOM = 4


class D3D12_CPU_PAGE_PROPERTY(IntFlag):
    D3D12_CPU_PAGE_PROPERTY_UNKNOWN = 0
    D3D12_CPU_PAGE_PROPERTY_NOT_AVAILABLE = 1
    D3D12_CPU_PAGE_PROPERTY_WRITE_COMBINE = 2
    D3D12_CPU_PAGE_PROPERTY_WRITE_BACK = 3


class D3D12_MEMORY_POOL(IntFlag):
    D3D12_MEMORY_POOL_UNKNOWN = 0
    D3D12_MEMORY_POOL_L0 = 1
    D3D12_MEMORY_POOL_L1 = 2


class D3D12_RESOURCE_STATES(IntFlag):
    D3D12_RESOURCE_STATE_COMMON = 0
    D3D12_RESOURCE_STATE_VERTEX_AND_CONSTANT_BUFFER = 1
    D3D12_RESOURCE_STATE_INDEX_BUFFER = 2
    D3D12_RESOURCE_STATE_RENDER_TARGET = 4
    D3D12_RESOURCE_STATE_UNORDERED_ACCESS = 8
    D3D12_RESOURCE_STATE_DEPTH_WRITE = 16
    D3D12_RESOURCE_STATE_DEPTH_READ = 32
    D3D12_RESOURCE_STATE_NON_PIXEL_SHADER_RESOURCE = 64
    D3D12_RESOURCE_STATE_PIXEL_SHADER_RESOURCE = 128
    D3D12_RESOURCE_STATE_STREAM_OUT = 256
    D3D12_RESOURCE_STATE_INDIRECT_ARGUMENT = 512
    D3D12_RESOURCE_STATE_COPY_DEST = 1024
    D3D12_RESOURCE_STATE_COPY_SOURCE = 2048
    D3D12_RESOURCE_STATE_RESOLVE_DEST = 4096
    D3D12_RESOURCE_STATE_RESOLVE_SOURCE = 8192
    D3D12_RESOURCE_STATE_RAYTRACING_ACCELERATION_STRUCTURE = 4194304
    D3D12_RESOURCE_STATE_SHADING_RATE_SOURCE = 16777216
    D3D12_RESOURCE_STATE_GENERIC_READ = 2755
    D3D12_RESOURCE_STATE_ALL_SHADER_RESOURCE = 192
    D3D12_RESOURCE_STATE_PRESENT = 0
    D3D12_RESOURCE_STATE_PREDICATION = 512
    D3D12_RESOURCE_STATE_VIDEO_DECODE_READ = 65536
    D3D12_RESOURCE_STATE_VIDEO_DECODE_WRITE = 131072
    D3D12_RESOURCE_STATE_VIDEO_PROCESS_READ = 262144
    D3D12_RESOURCE_STATE_VIDEO_PROCESS_WRITE = 524288
    D3D12_RESOURCE_STATE_VIDEO_ENCODE_READ = 2097152
    D3D12_RESOURCE_STATE_VIDEO_ENCODE_WRITE = 8388608


class D3D12_FENCE_FLAGS(IntFlag):
    D3D12_FENCE_FLAG_NONE = 0
    D3D12_FENCE_FLAG_SHARED = 1
    D3D12_FENCE_FLAG_SHARED_CROSS_ADAPTER = 2
    D3D12_FENCE_FLAG_NON_MONITORED = 4


class D3D12_MULTIPLE_FENCE_WAIT_FLAGS(IntFlag):
    D3D12_MULTIPLE_FENCE_WAIT_FLAG_NONE = 0
    D3D12_MULTIPLE_FENCE_WAIT_FLAG_ANY = 1
    D3D12_MULTIPLE_FENCE_WAIT_FLAG_ALL = 0


class D3D12_RESIDENCY_PRIORITY(IntFlag):
    D3D12_RESIDENCY_PRIORITY_MINIMUM = 671088640
    D3D12_RESIDENCY_PRIORITY_LOW = 1342177280
    D3D12_RESIDENCY_PRIORITY_NORMAL = 2013265920
    D3D12_RESIDENCY_PRIORITY_HIGH = -1610547200
    D3D12_RESIDENCY_PRIORITY_MAXIMUM = -939524096


class D3D12_ROOT_DESCRIPTOR_FLAGS(IntFlag):
    D3D12_ROOT_DESCRIPTOR_FLAG_NONE = 0
    D3D12_ROOT_DESCRIPTOR_FLAG_DATA_VOLATILE = 2
    D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE = 4
    D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC = 8


class D3D12_BLEND(IntFlag):
    D3D12_BLEND_ZERO = 1
    D3D12_BLEND_ONE = 2
    D3D12_BLEND_SRC_COLOR = 3
    D3D12_BLEND_INV_SRC_COLOR = 4
    D3D12_BLEND_SRC_ALPHA = 5
    D3D12_BLEND_INV_SRC_ALPHA = 6
    D3D12_BLEND_DEST_ALPHA = 7
    D3D12_BLEND_INV_DEST_ALPHA = 8
    D3D12_BLEND_DEST_COLOR = 9
    D3D12_BLEND_INV_DEST_COLOR = 10
    D3D12_BLEND_SRC_ALPHA_SAT = 11
    D3D12_BLEND_BLEND_FACTOR = 14
    D3D12_BLEND_INV_BLEND_FACTOR = 15
    D3D12_BLEND_SRC1_COLOR = 16
    D3D12_BLEND_INV_SRC1_COLOR = 17
    D3D12_BLEND_SRC1_ALPHA = 18
    D3D12_BLEND_INV_SRC1_ALPHA = 19
    D3D12_BLEND_ALPHA_FACTOR = 20
    D3D12_BLEND_INV_ALPHA_FACTOR = 21


class D3D12_FILL_MODE(IntFlag):
    D3D12_FILL_MODE_WIREFRAME = 2
    D3D12_FILL_MODE_SOLID = 3


class D3D12_CULL_MODE(IntFlag):
    D3D12_CULL_MODE_NONE = 1
    D3D12_CULL_MODE_FRONT = 2
    D3D12_CULL_MODE_BACK = 3


class D3D12_CONSERVATIVE_RASTERIZATION_MODE(IntFlag):
    D3D12_CONSERVATIVE_RASTERIZATION_MODE_OFF = 0
    D3D12_CONSERVATIVE_RASTERIZATION_MODE_ON = 1


class D3D12_DEPTH_WRITE_MASK(IntFlag):
    D3D12_DEPTH_WRITE_MASK_ZERO = 0
    D3D12_DEPTH_WRITE_MASK_ALL = 1


class D3D12_COMPARISON_FUNC(IntFlag):
    D3D12_COMPARISON_FUNC_NEVER = 1
    D3D12_COMPARISON_FUNC_LESS = 2
    D3D12_COMPARISON_FUNC_EQUAL = 3
    D3D12_COMPARISON_FUNC_LESS_EQUAL = 4
    D3D12_COMPARISON_FUNC_GREATER = 5
    D3D12_COMPARISON_FUNC_NOT_EQUAL = 6
    D3D12_COMPARISON_FUNC_GREATER_EQUAL = 7
    D3D12_COMPARISON_FUNC_ALWAYS = 8


class D3D12_STENCIL_OP(IntFlag):
    D3D12_STENCIL_OP_KEEP = 1
    D3D12_STENCIL_OP_ZERO = 2
    D3D12_STENCIL_OP_REPLACE = 3
    D3D12_STENCIL_OP_INCR_SAT = 4
    D3D12_STENCIL_OP_DECR_SAT = 5
    D3D12_STENCIL_OP_INVERT = 6
    D3D12_STENCIL_OP_INCR = 7
    D3D12_STENCIL_OP_DECR = 8


class D3D12_INDEX_BUFFER_STRIP_CUT_VALUE(IntFlag):
    D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_DISABLED = 0
    D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFF = 1
    D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFFFFFF = 2


class D3D12_PRIMITIVE_TOPOLOGY_TYPE(IntFlag):
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_UNDEFINED = 0
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_POINT = 1
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_LINE = 2
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_TRIANGLE = 3
    D3D12_PRIMITIVE_TOPOLOGY_TYPE_PATCH = 4


class DXGI_FORMAT(IntFlag):
    DXGI_FORMAT_UNKNOWN = 0
    DXGI_FORMAT_R32G32B32A32_TYPELESS = 1
    DXGI_FORMAT_R32G32B32A32_FLOAT = 2
    DXGI_FORMAT_R32G32B32A32_UINT = 3
    DXGI_FORMAT_R32G32B32A32_SINT = 4
    DXGI_FORMAT_R32G32B32_TYPELESS = 5
    DXGI_FORMAT_R32G32B32_FLOAT = 6
    DXGI_FORMAT_R32G32B32_UINT = 7
    DXGI_FORMAT_R32G32B32_SINT = 8
    DXGI_FORMAT_R16G16B16A16_TYPELESS = 9
    DXGI_FORMAT_R16G16B16A16_FLOAT = 10
    DXGI_FORMAT_R16G16B16A16_UNORM = 11
    DXGI_FORMAT_R16G16B16A16_UINT = 12
    DXGI_FORMAT_R16G16B16A16_SNORM = 13
    DXGI_FORMAT_R16G16B16A16_SINT = 14
    DXGI_FORMAT_R32G32_TYPELESS = 15
    DXGI_FORMAT_R32G32_FLOAT = 16
    DXGI_FORMAT_R32G32_UINT = 17
    DXGI_FORMAT_R32G32_SINT = 18
    DXGI_FORMAT_R32G8X24_TYPELESS = 19
    DXGI_FORMAT_D32_FLOAT_S8X24_UINT = 20
    DXGI_FORMAT_R32_FLOAT_X8X24_TYPELESS = 21
    DXGI_FORMAT_X32_TYPELESS_G8X24_UINT = 22
    DXGI_FORMAT_R10G10B10A2_TYPELESS = 23
    DXGI_FORMAT_R10G10B10A2_UNORM = 24
    DXGI_FORMAT_R10G10B10A2_UINT = 25
    DXGI_FORMAT_R11G11B10_FLOAT = 26
    DXGI_FORMAT_R8G8B8A8_TYPELESS = 27
    DXGI_FORMAT_R8G8B8A8_UNORM = 28
    DXGI_FORMAT_R8G8B8A8_UNORM_SRGB = 29
    DXGI_FORMAT_R8G8B8A8_UINT = 30
    DXGI_FORMAT_R8G8B8A8_SNORM = 31
    DXGI_FORMAT_R8G8B8A8_SINT = 32
    DXGI_FORMAT_R16G16_TYPELESS = 33
    DXGI_FORMAT_R16G16_FLOAT = 34
    DXGI_FORMAT_R16G16_UNORM = 35
    DXGI_FORMAT_R16G16_UINT = 36
    DXGI_FORMAT_R16G16_SNORM = 37
    DXGI_FORMAT_R16G16_SINT = 38
    DXGI_FORMAT_R32_TYPELESS = 39
    DXGI_FORMAT_D32_FLOAT = 40
    DXGI_FORMAT_R32_FLOAT = 41
    DXGI_FORMAT_R32_UINT = 42
    DXGI_FORMAT_R32_SINT = 43
    DXGI_FORMAT_R24G8_TYPELESS = 44
    DXGI_FORMAT_D24_UNORM_S8_UINT = 45
    DXGI_FORMAT_R24_UNORM_X8_TYPELESS = 46
    DXGI_FORMAT_X24_TYPELESS_G8_UINT = 47
    DXGI_FORMAT_R8G8_TYPELESS = 48
    DXGI_FORMAT_R8G8_UNORM = 49
    DXGI_FORMAT_R8G8_UINT = 50
    DXGI_FORMAT_R8G8_SNORM = 51
    DXGI_FORMAT_R8G8_SINT = 52
    DXGI_FORMAT_R16_TYPELESS = 53
    DXGI_FORMAT_R16_FLOAT = 54
    DXGI_FORMAT_D16_UNORM = 55
    DXGI_FORMAT_R16_UNORM = 56
    DXGI_FORMAT_R16_UINT = 57
    DXGI_FORMAT_R16_SNORM = 58
    DXGI_FORMAT_R16_SINT = 59
    DXGI_FORMAT_R8_TYPELESS = 60
    DXGI_FORMAT_R8_UNORM = 61
    DXGI_FORMAT_R8_UINT = 62
    DXGI_FORMAT_R8_SNORM = 63
    DXGI_FORMAT_R8_SINT = 64
    DXGI_FORMAT_A8_UNORM = 65
    DXGI_FORMAT_R1_UNORM = 66
    DXGI_FORMAT_R9G9B9E5_SHAREDEXP = 67
    DXGI_FORMAT_R8G8_B8G8_UNORM = 68
    DXGI_FORMAT_G8R8_G8B8_UNORM = 69
    DXGI_FORMAT_BC1_TYPELESS = 70
    DXGI_FORMAT_BC1_UNORM = 71
    DXGI_FORMAT_BC1_UNORM_SRGB = 72
    DXGI_FORMAT_BC2_TYPELESS = 73
    DXGI_FORMAT_BC2_UNORM = 74
    DXGI_FORMAT_BC2_UNORM_SRGB = 75
    DXGI_FORMAT_BC3_TYPELESS = 76
    DXGI_FORMAT_BC3_UNORM = 77
    DXGI_FORMAT_BC3_UNORM_SRGB = 78
    DXGI_FORMAT_BC4_TYPELESS = 79
    DXGI_FORMAT_BC4_UNORM = 80
    DXGI_FORMAT_BC4_SNORM = 81
    DXGI_FORMAT_BC5_TYPELESS = 82
    DXGI_FORMAT_BC5_UNORM = 83
    DXGI_FORMAT_BC5_SNORM = 84
    DXGI_FORMAT_B5G6R5_UNORM = 85
    DXGI_FORMAT_B5G5R5A1_UNORM = 86
    DXGI_FORMAT_B8G8R8A8_UNORM = 87
    DXGI_FORMAT_B8G8R8X8_UNORM = 88
    DXGI_FORMAT_R10G10B10_XR_BIAS_A2_UNORM = 89
    DXGI_FORMAT_B8G8R8A8_TYPELESS = 90
    DXGI_FORMAT_B8G8R8A8_UNORM_SRGB = 91
    DXGI_FORMAT_B8G8R8X8_TYPELESS = 92
    DXGI_FORMAT_B8G8R8X8_UNORM_SRGB = 93
    DXGI_FORMAT_BC6H_TYPELESS = 94
    DXGI_FORMAT_BC6H_UF16 = 95
    DXGI_FORMAT_BC6H_SF16 = 96
    DXGI_FORMAT_BC7_TYPELESS = 97
    DXGI_FORMAT_BC7_UNORM = 98
    DXGI_FORMAT_BC7_UNORM_SRGB = 99
    DXGI_FORMAT_AYUV = 100
    DXGI_FORMAT_Y410 = 101
    DXGI_FORMAT_Y416 = 102
    DXGI_FORMAT_NV12 = 103
    DXGI_FORMAT_P010 = 104
    DXGI_FORMAT_P016 = 105
    DXGI_FORMAT_420_OPAQUE = 106
    DXGI_FORMAT_YUY2 = 107
    DXGI_FORMAT_Y210 = 108
    DXGI_FORMAT_Y216 = 109
    DXGI_FORMAT_NV11 = 110
    DXGI_FORMAT_AI44 = 111
    DXGI_FORMAT_IA44 = 112
    DXGI_FORMAT_P8 = 113
    DXGI_FORMAT_A8P8 = 114
    DXGI_FORMAT_B4G4R4A4_UNORM = 115
    DXGI_FORMAT_P208 = 130
    DXGI_FORMAT_V208 = 131
    DXGI_FORMAT_V408 = 132
    DXGI_FORMAT_SAMPLER_FEEDBACK_MIN_MIP_OPAQUE = 189
    DXGI_FORMAT_SAMPLER_FEEDBACK_MIP_REGION_USED_OPAQUE = 190
    DXGI_FORMAT_FORCE_UINT = -1


class D3D12_PIPELINE_STATE_FLAGS(IntFlag):
    D3D12_PIPELINE_STATE_FLAG_NONE = 0
    D3D12_PIPELINE_STATE_FLAG_TOOL_DEBUG = 1


class D3D12_ROOT_PARAMETER_TYPE(IntFlag):
    D3D12_ROOT_PARAMETER_TYPE_DESCRIPTOR_TABLE = 0
    D3D12_ROOT_PARAMETER_TYPE_32BIT_CONSTANTS = 1
    D3D12_ROOT_PARAMETER_TYPE_CBV = 2
    D3D12_ROOT_PARAMETER_TYPE_SRV = 3
    D3D12_ROOT_PARAMETER_TYPE_UAV = 4


class D3D12_DESCRIPTOR_RANGE_TYPE(IntFlag):
    D3D12_DESCRIPTOR_RANGE_TYPE_SRV = 0
    D3D12_DESCRIPTOR_RANGE_TYPE_UAV = 1
    D3D12_DESCRIPTOR_RANGE_TYPE_CBV = 2
    D3D12_DESCRIPTOR_RANGE_TYPE_SAMPLER = 3


class D3D12_ROOT_SIGNATURE_FLAGS(IntFlag):
    D3D12_ROOT_SIGNATURE_FLAG_NONE = 0
    D3D12_ROOT_SIGNATURE_FLAG_ALLOW_INPUT_ASSEMBLER_INPUT_LAYOUT = 1
    D3D12_ROOT_SIGNATURE_FLAG_DENY_VERTEX_SHADER_ROOT_ACCESS = 2
    D3D12_ROOT_SIGNATURE_FLAG_DENY_HULL_SHADER_ROOT_ACCESS = 4
    D3D12_ROOT_SIGNATURE_FLAG_DENY_DOMAIN_SHADER_ROOT_ACCESS = 8
    D3D12_ROOT_SIGNATURE_FLAG_DENY_GEOMETRY_SHADER_ROOT_ACCESS = 16
    D3D12_ROOT_SIGNATURE_FLAG_DENY_PIXEL_SHADER_ROOT_ACCESS = 32
    D3D12_ROOT_SIGNATURE_FLAG_ALLOW_STREAM_OUTPUT = 64
    D3D12_ROOT_SIGNATURE_FLAG_LOCAL_ROOT_SIGNATURE = 128
    D3D12_ROOT_SIGNATURE_FLAG_DENY_AMPLIFICATION_SHADER_ROOT_ACCESS = 256
    D3D12_ROOT_SIGNATURE_FLAG_DENY_MESH_SHADER_ROOT_ACCESS = 512
    D3D12_ROOT_SIGNATURE_FLAG_CBV_SRV_UAV_HEAP_DIRECTLY_INDEXED = 1024
    D3D12_ROOT_SIGNATURE_FLAG_SAMPLER_HEAP_DIRECTLY_INDEXED = 2048


class D3D12_UAV_DIMENSION(IntFlag):
    D3D12_UAV_DIMENSION_UNKNOWN = 0
    D3D12_UAV_DIMENSION_BUFFER = 1
    D3D12_UAV_DIMENSION_TEXTURE1D = 2
    D3D12_UAV_DIMENSION_TEXTURE1DARRAY = 3
    D3D12_UAV_DIMENSION_TEXTURE2D = 4
    D3D12_UAV_DIMENSION_TEXTURE2DARRAY = 5
    D3D12_UAV_DIMENSION_TEXTURE3D = 8


class D3D12_BUFFER_UAV_FLAGS(IntFlag):
    D3D12_BUFFER_UAV_FLAG_NONE = 0
    D3D12_BUFFER_UAV_FLAG_RAW = 1


class D3D12_SHADER_VISIBILITY(IntFlag):
    D3D12_SHADER_VISIBILITY_ALL = 0
    D3D12_SHADER_VISIBILITY_VERTEX = 1
    D3D12_SHADER_VISIBILITY_HULL = 2
    D3D12_SHADER_VISIBILITY_DOMAIN = 3
    D3D12_SHADER_VISIBILITY_GEOMETRY = 4
    D3D12_SHADER_VISIBILITY_PIXEL = 5
    D3D12_SHADER_VISIBILITY_AMPLIFICATION = 6
    D3D12_SHADER_VISIBILITY_MESH = 7


class D3D12_STATIC_BORDER_COLOR(IntFlag):
    D3D12_STATIC_BORDER_COLOR_TRANSPARENT_BLACK = 0
    D3D12_STATIC_BORDER_COLOR_OPAQUE_BLACK = 1
    D3D12_STATIC_BORDER_COLOR_OPAQUE_WHITE = 2


class D3D12_BUFFER_SRV_FLAGS(IntFlag):
    D3D12_BUFFER_SRV_FLAG_NONE = 0
    D3D12_BUFFER_SRV_FLAG_RAW = 1


class D3D12_RTV_DIMENSION(IntFlag):
    D3D12_RTV_DIMENSION_UNKNOWN = 0
    D3D12_RTV_DIMENSION_BUFFER = 1
    D3D12_RTV_DIMENSION_TEXTURE1D = 2
    D3D12_RTV_DIMENSION_TEXTURE1DARRAY = 3
    D3D12_RTV_DIMENSION_TEXTURE2D = 4
    D3D12_RTV_DIMENSION_TEXTURE2DARRAY = 5
    D3D12_RTV_DIMENSION_TEXTURE2DMS = 6
    D3D12_RTV_DIMENSION_TEXTURE2DMSARRAY = 7
    D3D12_RTV_DIMENSION_TEXTURE3D = 8


class D3D_ROOT_SIGNATURE_VERSION(IntFlag):
    D3D_ROOT_SIGNATURE_VERSION_1 = 1
    D3D_ROOT_SIGNATURE_VERSION_1_0 = 1
    D3D_ROOT_SIGNATURE_VERSION_1_1 = 2


class D3D12_DESCRIPTOR_RANGE_FLAGS(IntFlag):
    D3D12_DESCRIPTOR_RANGE_FLAG_NONE = 0
    D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_VOLATILE = 1
    D3D12_DESCRIPTOR_RANGE_FLAG_DATA_VOLATILE = 2
    D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE = 4
    D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC = 8
    D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_STATIC_KEEPING_BUFFER_BOUNDS_CHECKS = 65536


class D3D12_DSV_DIMENSION(IntFlag):
    D3D12_DSV_DIMENSION_UNKNOWN = 0
    D3D12_DSV_DIMENSION_TEXTURE1D = 1
    D3D12_DSV_DIMENSION_TEXTURE1DARRAY = 2
    D3D12_DSV_DIMENSION_TEXTURE2D = 3
    D3D12_DSV_DIMENSION_TEXTURE2DARRAY = 4
    D3D12_DSV_DIMENSION_TEXTURE2DMS = 5
    D3D12_DSV_DIMENSION_TEXTURE2DMSARRAY = 6


class D3D12_DSV_FLAGS(IntFlag):
    D3D12_DSV_FLAG_NONE = 0
    D3D12_DSV_FLAG_READ_ONLY_DEPTH = 1
    D3D12_DSV_FLAG_READ_ONLY_STENCIL = 2


class D3D12_TILE_MAPPING_FLAGS(IntFlag):
    D3D12_TILE_MAPPING_FLAG_NONE = 0
    D3D12_TILE_MAPPING_FLAG_NO_HAZARD = 1


class D3D12_COMMAND_QUEUE_FLAGS(IntFlag):
    D3D12_COMMAND_QUEUE_FLAG_NONE = 0
    D3D12_COMMAND_QUEUE_FLAG_DISABLE_GPU_TIMEOUT = 1


class D3D12_DRED_ENABLEMENT(IntFlag):
    D3D12_DRED_ENABLEMENT_SYSTEM_CONTROLLED = 0
    D3D12_DRED_ENABLEMENT_FORCED_OFF = 1
    D3D12_DRED_ENABLEMENT_FORCED_ON = 2


class D3D12_INPUT_CLASSIFICATION(IntFlag):
    D3D12_INPUT_CLASSIFICATION_PER_VERTEX_DATA = 0
    D3D12_INPUT_CLASSIFICATION_PER_INSTANCE_DATA = 1


class D3D12_RESOURCE_DIMENSION(IntFlag):
    D3D12_RESOURCE_DIMENSION_UNKNOWN = 0
    D3D12_RESOURCE_DIMENSION_BUFFER = 1
    D3D12_RESOURCE_DIMENSION_TEXTURE1D = 2
    D3D12_RESOURCE_DIMENSION_TEXTURE2D = 3
    D3D12_RESOURCE_DIMENSION_TEXTURE3D = 4


class D3D12_AUTO_BREADCRUMB_OP(IntFlag):
    D3D12_AUTO_BREADCRUMB_OP_SETMARKER = 0
    D3D12_AUTO_BREADCRUMB_OP_BEGINEVENT = 1
    D3D12_AUTO_BREADCRUMB_OP_ENDEVENT = 2
    D3D12_AUTO_BREADCRUMB_OP_DRAWINSTANCED = 3
    D3D12_AUTO_BREADCRUMB_OP_DRAWINDEXEDINSTANCED = 4
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEINDIRECT = 5
    D3D12_AUTO_BREADCRUMB_OP_DISPATCH = 6
    D3D12_AUTO_BREADCRUMB_OP_COPYBUFFERREGION = 7
    D3D12_AUTO_BREADCRUMB_OP_COPYTEXTUREREGION = 8
    D3D12_AUTO_BREADCRUMB_OP_COPYRESOURCE = 9
    D3D12_AUTO_BREADCRUMB_OP_COPYTILES = 10
    D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCE = 11
    D3D12_AUTO_BREADCRUMB_OP_CLEARRENDERTARGETVIEW = 12
    D3D12_AUTO_BREADCRUMB_OP_CLEARUNORDEREDACCESSVIEW = 13
    D3D12_AUTO_BREADCRUMB_OP_CLEARDEPTHSTENCILVIEW = 14
    D3D12_AUTO_BREADCRUMB_OP_RESOURCEBARRIER = 15
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEBUNDLE = 16
    D3D12_AUTO_BREADCRUMB_OP_PRESENT = 17
    D3D12_AUTO_BREADCRUMB_OP_RESOLVEQUERYDATA = 18
    D3D12_AUTO_BREADCRUMB_OP_BEGINSUBMISSION = 19
    D3D12_AUTO_BREADCRUMB_OP_ENDSUBMISSION = 20
    D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME = 21
    D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES = 22
    D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT = 23
    D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT64 = 24
    D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCEREGION = 25
    D3D12_AUTO_BREADCRUMB_OP_WRITEBUFFERIMMEDIATE = 26
    D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME1 = 27
    D3D12_AUTO_BREADCRUMB_OP_SETPROTECTEDRESOURCESESSION = 28
    D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME2 = 29
    D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES1 = 30
    D3D12_AUTO_BREADCRUMB_OP_BUILDRAYTRACINGACCELERATIONSTRUCTURE = 31
    D3D12_AUTO_BREADCRUMB_OP_EMITRAYTRACINGACCELERATIONSTRUCTUREPOSTBUILDINFO = 32
    D3D12_AUTO_BREADCRUMB_OP_COPYRAYTRACINGACCELERATIONSTRUCTURE = 33
    D3D12_AUTO_BREADCRUMB_OP_DISPATCHRAYS = 34
    D3D12_AUTO_BREADCRUMB_OP_INITIALIZEMETACOMMAND = 35
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEMETACOMMAND = 36
    D3D12_AUTO_BREADCRUMB_OP_ESTIMATEMOTION = 37
    D3D12_AUTO_BREADCRUMB_OP_RESOLVEMOTIONVECTORHEAP = 38
    D3D12_AUTO_BREADCRUMB_OP_SETPIPELINESTATE1 = 39
    D3D12_AUTO_BREADCRUMB_OP_INITIALIZEEXTENSIONCOMMAND = 40
    D3D12_AUTO_BREADCRUMB_OP_EXECUTEEXTENSIONCOMMAND = 41
    D3D12_AUTO_BREADCRUMB_OP_DISPATCHMESH = 42
    D3D12_AUTO_BREADCRUMB_OP_ENCODEFRAME = 43
    D3D12_AUTO_BREADCRUMB_OP_RESOLVEENCODEROUTPUTMETADATA = 44


class D3D12_FILTER(IntFlag):
    D3D12_FILTER_MIN_MAG_MIP_POINT = 0
    D3D12_FILTER_MIN_MAG_POINT_MIP_LINEAR = 1
    D3D12_FILTER_MIN_POINT_MAG_LINEAR_MIP_POINT = 4
    D3D12_FILTER_MIN_POINT_MAG_MIP_LINEAR = 5
    D3D12_FILTER_MIN_LINEAR_MAG_MIP_POINT = 16
    D3D12_FILTER_MIN_LINEAR_MAG_POINT_MIP_LINEAR = 17
    D3D12_FILTER_MIN_MAG_LINEAR_MIP_POINT = 20
    D3D12_FILTER_MIN_MAG_MIP_LINEAR = 21
    D3D12_FILTER_ANISOTROPIC = 85
    D3D12_FILTER_COMPARISON_MIN_MAG_MIP_POINT = 128
    D3D12_FILTER_COMPARISON_MIN_MAG_POINT_MIP_LINEAR = 129
    D3D12_FILTER_COMPARISON_MIN_POINT_MAG_LINEAR_MIP_POINT = 132
    D3D12_FILTER_COMPARISON_MIN_POINT_MAG_MIP_LINEAR = 133
    D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_MIP_POINT = 144
    D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_POINT_MIP_LINEAR = 145
    D3D12_FILTER_COMPARISON_MIN_MAG_LINEAR_MIP_POINT = 148
    D3D12_FILTER_COMPARISON_MIN_MAG_MIP_LINEAR = 149
    D3D12_FILTER_COMPARISON_ANISOTROPIC = 213
    D3D12_FILTER_MINIMUM_MIN_MAG_MIP_POINT = 256
    D3D12_FILTER_MINIMUM_MIN_MAG_POINT_MIP_LINEAR = 257
    D3D12_FILTER_MINIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT = 260
    D3D12_FILTER_MINIMUM_MIN_POINT_MAG_MIP_LINEAR = 261
    D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_MIP_POINT = 272
    D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR = 273
    D3D12_FILTER_MINIMUM_MIN_MAG_LINEAR_MIP_POINT = 276
    D3D12_FILTER_MINIMUM_MIN_MAG_MIP_LINEAR = 277
    D3D12_FILTER_MINIMUM_ANISOTROPIC = 341
    D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_POINT = 384
    D3D12_FILTER_MAXIMUM_MIN_MAG_POINT_MIP_LINEAR = 385
    D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT = 388
    D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_MIP_LINEAR = 389
    D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_MIP_POINT = 400
    D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR = 401
    D3D12_FILTER_MAXIMUM_MIN_MAG_LINEAR_MIP_POINT = 404
    D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_LINEAR = 405
    D3D12_FILTER_MAXIMUM_ANISOTROPIC = 469


class D3D12_TEXTURE_ADDRESS_MODE(IntFlag):
    D3D12_TEXTURE_ADDRESS_MODE_WRAP = 1
    D3D12_TEXTURE_ADDRESS_MODE_MIRROR = 2
    D3D12_TEXTURE_ADDRESS_MODE_CLAMP = 3
    D3D12_TEXTURE_ADDRESS_MODE_BORDER = 4
    D3D12_TEXTURE_ADDRESS_MODE_MIRROR_ONCE = 5


class D3D12_SRV_DIMENSION(IntFlag):
    D3D12_SRV_DIMENSION_UNKNOWN = 0
    D3D12_SRV_DIMENSION_BUFFER = 1
    D3D12_SRV_DIMENSION_TEXTURE1D = 2
    D3D12_SRV_DIMENSION_TEXTURE1DARRAY = 3
    D3D12_SRV_DIMENSION_TEXTURE2D = 4
    D3D12_SRV_DIMENSION_TEXTURE2DARRAY = 5
    D3D12_SRV_DIMENSION_TEXTURE2DMS = 6
    D3D12_SRV_DIMENSION_TEXTURE2DMSARRAY = 7
    D3D12_SRV_DIMENSION_TEXTURE3D = 8
    D3D12_SRV_DIMENSION_TEXTURECUBE = 9
    D3D12_SRV_DIMENSION_TEXTURECUBEARRAY = 10
    D3D12_SRV_DIMENSION_RAYTRACING_ACCELERATION_STRUCTURE = 11


class D3D12_DRED_ALLOCATION_TYPE(IntFlag):
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_QUEUE = 19
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_ALLOCATOR = 20
    D3D12_DRED_ALLOCATION_TYPE_PIPELINE_STATE = 21
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_LIST = 22
    D3D12_DRED_ALLOCATION_TYPE_FENCE = 23
    D3D12_DRED_ALLOCATION_TYPE_DESCRIPTOR_HEAP = 24
    D3D12_DRED_ALLOCATION_TYPE_HEAP = 25
    D3D12_DRED_ALLOCATION_TYPE_QUERY_HEAP = 27
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_SIGNATURE = 28
    D3D12_DRED_ALLOCATION_TYPE_PIPELINE_LIBRARY = 29
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER = 30
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_PROCESSOR = 32
    D3D12_DRED_ALLOCATION_TYPE_RESOURCE = 34
    D3D12_DRED_ALLOCATION_TYPE_PASS = 35
    D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSION = 36
    D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSIONPOLICY = 37
    D3D12_DRED_ALLOCATION_TYPE_PROTECTEDRESOURCESESSION = 38
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER_HEAP = 39
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_POOL = 40
    D3D12_DRED_ALLOCATION_TYPE_COMMAND_RECORDER = 41
    D3D12_DRED_ALLOCATION_TYPE_STATE_OBJECT = 42
    D3D12_DRED_ALLOCATION_TYPE_METACOMMAND = 43
    D3D12_DRED_ALLOCATION_TYPE_SCHEDULINGGROUP = 44
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_ESTIMATOR = 45
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_VECTOR_HEAP = 46
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_EXTENSION_COMMAND = 47
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER = 48
    D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER_HEAP = 49
    D3D12_DRED_ALLOCATION_TYPE_INVALID = -1


class D3D12_RESOLVE_MODE(IntFlag):
    D3D12_RESOLVE_MODE_DECOMPRESS = 0
    D3D12_RESOLVE_MODE_MIN = 1
    D3D12_RESOLVE_MODE_MAX = 2
    D3D12_RESOLVE_MODE_AVERAGE = 3
    D3D12_RESOLVE_MODE_ENCODE_SAMPLER_FEEDBACK = 4
    D3D12_RESOLVE_MODE_DECODE_SAMPLER_FEEDBACK = 5


class D3D12_MEASUREMENTS_ACTION(IntFlag):
    D3D12_MEASUREMENTS_ACTION_KEEP_ALL = 0
    D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS = 1
    D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS_HIGH_PRIORITY = 2
    D3D12_MEASUREMENTS_ACTION_DISCARD_PREVIOUS = 3


class D3D12_QUERY_HEAP_TYPE(IntFlag):
    D3D12_QUERY_HEAP_TYPE_OCCLUSION = 0
    D3D12_QUERY_HEAP_TYPE_TIMESTAMP = 1
    D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS = 2
    D3D12_QUERY_HEAP_TYPE_SO_STATISTICS = 3
    D3D12_QUERY_HEAP_TYPE_VIDEO_DECODE_STATISTICS = 4
    D3D12_QUERY_HEAP_TYPE_COPY_QUEUE_TIMESTAMP = 5
    D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS1 = 7


class D3D12_TILE_COPY_FLAGS(IntFlag):
    D3D12_TILE_COPY_FLAG_NONE = 0
    D3D12_TILE_COPY_FLAG_NO_HAZARD = 1
    D3D12_TILE_COPY_FLAG_LINEAR_BUFFER_TO_SWIZZLED_TILED_RESOURCE = 2
    D3D12_TILE_COPY_FLAG_SWIZZLED_TILED_RESOURCE_TO_LINEAR_BUFFER = 4


class D3D_PRIMITIVE_TOPOLOGY(IntFlag):
    D3D_PRIMITIVE_TOPOLOGY_UNDEFINED = 0
    D3D_PRIMITIVE_TOPOLOGY_POINTLIST = 1
    D3D_PRIMITIVE_TOPOLOGY_LINELIST = 2
    D3D_PRIMITIVE_TOPOLOGY_LINESTRIP = 3
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST = 4
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP = 5
    D3D_PRIMITIVE_TOPOLOGY_LINELIST_ADJ = 10
    D3D_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ = 11
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ = 12
    D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ = 13
    D3D_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST = 33
    D3D_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST = 34
    D3D_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST = 35
    D3D_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST = 36
    D3D_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST = 37
    D3D_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST = 38
    D3D_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST = 39
    D3D_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST = 40
    D3D_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST = 41
    D3D_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST = 42
    D3D_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST = 43
    D3D_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST = 44
    D3D_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST = 45
    D3D_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST = 46
    D3D_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST = 47
    D3D_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST = 48
    D3D_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST = 49
    D3D_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST = 50
    D3D_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST = 51
    D3D_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST = 52
    D3D_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST = 53
    D3D_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST = 54
    D3D_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST = 55
    D3D_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST = 56
    D3D_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST = 57
    D3D_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST = 58
    D3D_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST = 59
    D3D_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST = 60
    D3D_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST = 61
    D3D_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST = 62
    D3D_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST = 63
    D3D_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST = 64
    D3D10_PRIMITIVE_TOPOLOGY_UNDEFINED = 0
    D3D10_PRIMITIVE_TOPOLOGY_POINTLIST = 1
    D3D10_PRIMITIVE_TOPOLOGY_LINELIST = 2
    D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP = 3
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST = 4
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP = 5
    D3D10_PRIMITIVE_TOPOLOGY_LINELIST_ADJ = 10
    D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ = 11
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ = 12
    D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ = 13
    D3D11_PRIMITIVE_TOPOLOGY_UNDEFINED = 0
    D3D11_PRIMITIVE_TOPOLOGY_POINTLIST = 1
    D3D11_PRIMITIVE_TOPOLOGY_LINELIST = 2
    D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP = 3
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST = 4
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP = 5
    D3D11_PRIMITIVE_TOPOLOGY_LINELIST_ADJ = 10
    D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ = 11
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ = 12
    D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ = 13
    D3D11_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST = 33
    D3D11_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST = 34
    D3D11_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST = 35
    D3D11_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST = 36
    D3D11_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST = 37
    D3D11_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST = 38
    D3D11_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST = 39
    D3D11_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST = 40
    D3D11_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST = 41
    D3D11_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST = 42
    D3D11_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST = 43
    D3D11_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST = 44
    D3D11_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST = 45
    D3D11_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST = 46
    D3D11_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST = 47
    D3D11_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST = 48
    D3D11_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST = 49
    D3D11_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST = 50
    D3D11_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST = 51
    D3D11_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST = 52
    D3D11_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST = 53
    D3D11_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST = 54
    D3D11_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST = 55
    D3D11_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST = 56
    D3D11_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST = 57
    D3D11_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST = 58
    D3D11_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST = 59
    D3D11_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST = 60
    D3D11_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST = 61
    D3D11_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST = 62
    D3D11_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST = 63
    D3D11_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST = 64


class D3D12_CLEAR_FLAGS(IntFlag):
    D3D12_CLEAR_FLAG_DEPTH = 1
    D3D12_CLEAR_FLAG_STENCIL = 2


class D3D12_QUERY_TYPE(IntFlag):
    D3D12_QUERY_TYPE_OCCLUSION = 0
    D3D12_QUERY_TYPE_BINARY_OCCLUSION = 1
    D3D12_QUERY_TYPE_TIMESTAMP = 2
    D3D12_QUERY_TYPE_PIPELINE_STATISTICS = 3
    D3D12_QUERY_TYPE_SO_STATISTICS_STREAM0 = 4
    D3D12_QUERY_TYPE_SO_STATISTICS_STREAM1 = 5
    D3D12_QUERY_TYPE_SO_STATISTICS_STREAM2 = 6
    D3D12_QUERY_TYPE_SO_STATISTICS_STREAM3 = 7
    D3D12_QUERY_TYPE_VIDEO_DECODE_STATISTICS = 8
    D3D12_QUERY_TYPE_PIPELINE_STATISTICS1 = 10


class D3D12_PREDICATION_OP(IntFlag):
    D3D12_PREDICATION_OP_EQUAL_ZERO = 0
    D3D12_PREDICATION_OP_NOT_EQUAL_ZERO = 1


class D3D12_INDIRECT_ARGUMENT_TYPE(IntFlag):
    D3D12_INDIRECT_ARGUMENT_TYPE_DRAW = 0
    D3D12_INDIRECT_ARGUMENT_TYPE_DRAW_INDEXED = 1
    D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH = 2
    D3D12_INDIRECT_ARGUMENT_TYPE_VERTEX_BUFFER_VIEW = 3
    D3D12_INDIRECT_ARGUMENT_TYPE_INDEX_BUFFER_VIEW = 4
    D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT = 5
    D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT_BUFFER_VIEW = 6
    D3D12_INDIRECT_ARGUMENT_TYPE_SHADER_RESOURCE_VIEW = 7
    D3D12_INDIRECT_ARGUMENT_TYPE_UNORDERED_ACCESS_VIEW = 8
    D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_RAYS = 9
    D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_MESH = 10


class D3D12_WRITEBUFFERIMMEDIATE_MODE(IntFlag):
    D3D12_WRITEBUFFERIMMEDIATE_MODE_DEFAULT = 0
    D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_IN = 1
    D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_OUT = 2


class D3D12_RENDER_PASS_FLAGS(IntFlag):
    D3D12_RENDER_PASS_FLAG_NONE = 0
    D3D12_RENDER_PASS_FLAG_ALLOW_UAV_WRITES = 1
    D3D12_RENDER_PASS_FLAG_SUSPENDING_PASS = 2
    D3D12_RENDER_PASS_FLAG_RESUMING_PASS = 4


class D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE(IntFlag):
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_DISCARD = 0
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_PRESERVE = 1
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_CLEAR = 2
    D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_NO_ACCESS = 3


class D3D12_RENDER_PASS_ENDING_ACCESS_TYPE(IntFlag):
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_DISCARD = 0
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_PRESERVE = 1
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_RESOLVE = 2
    D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_NO_ACCESS = 3


class D3D12_SHADER_CACHE_MODE(IntFlag):
    D3D12_SHADER_CACHE_MODE_MEMORY = 0
    D3D12_SHADER_CACHE_MODE_DISK = 1


class D3D12_META_COMMAND_PARAMETER_STAGE(IntFlag):
    D3D12_META_COMMAND_PARAMETER_STAGE_CREATION = 0
    D3D12_META_COMMAND_PARAMETER_STAGE_INITIALIZATION = 1
    D3D12_META_COMMAND_PARAMETER_STAGE_EXECUTION = 2


class D3D12_TEXTURE_LAYOUT(IntFlag):
    D3D12_TEXTURE_LAYOUT_UNKNOWN = 0
    D3D12_TEXTURE_LAYOUT_ROW_MAJOR = 1
    D3D12_TEXTURE_LAYOUT_64KB_UNDEFINED_SWIZZLE = 2
    D3D12_TEXTURE_LAYOUT_64KB_STANDARD_SWIZZLE = 3


class D3D12_RESOURCE_FLAGS(IntFlag):
    D3D12_RESOURCE_FLAG_NONE = 0
    D3D12_RESOURCE_FLAG_ALLOW_RENDER_TARGET = 1
    D3D12_RESOURCE_FLAG_ALLOW_DEPTH_STENCIL = 2
    D3D12_RESOURCE_FLAG_ALLOW_UNORDERED_ACCESS = 4
    D3D12_RESOURCE_FLAG_DENY_SHADER_RESOURCE = 8
    D3D12_RESOURCE_FLAG_ALLOW_CROSS_ADAPTER = 16
    D3D12_RESOURCE_FLAG_ALLOW_SIMULTANEOUS_ACCESS = 32
    D3D12_RESOURCE_FLAG_VIDEO_DECODE_REFERENCE_ONLY = 64
    D3D12_RESOURCE_FLAG_VIDEO_ENCODE_REFERENCE_ONLY = 128
    D3D12_RESOURCE_FLAG_RAYTRACING_ACCELERATION_STRUCTURE = 256


class D3D12_SHADER_CACHE_FLAGS(IntFlag):
    D3D12_SHADER_CACHE_FLAG_NONE = 0
    D3D12_SHADER_CACHE_FLAG_DRIVER_VERSIONED = 1
    D3D12_SHADER_CACHE_FLAG_USE_WORKING_DIR = 2


class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE(IntFlag):
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_TOP_LEVEL = 0
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_BOTTOM_LEVEL = 1


class D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS(IntFlag):
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_NONE = 0
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_UPDATE = 1
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_COMPACTION = 2
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_TRACE = 4
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_BUILD = 8
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_MINIMIZE_MEMORY = 16
    D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PERFORM_UPDATE = 32


class D3D12_ELEMENTS_LAYOUT(IntFlag):
    D3D12_ELEMENTS_LAYOUT_ARRAY = 0
    D3D12_ELEMENTS_LAYOUT_ARRAY_OF_POINTERS = 1


class D3D12_SHADER_CACHE_KIND_FLAGS(IntFlag):
    D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CACHE_FOR_DRIVER = 1
    D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CONVERSIONS = 2
    D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_DRIVER_MANAGED = 4
    D3D12_SHADER_CACHE_KIND_FLAG_APPLICATION_MANAGED = 8


class D3D12_SHADER_CACHE_CONTROL_FLAGS(IntFlag):
    D3D12_SHADER_CACHE_CONTROL_FLAG_DISABLE = 1
    D3D12_SHADER_CACHE_CONTROL_FLAG_ENABLE = 2
    D3D12_SHADER_CACHE_CONTROL_FLAG_CLEAR = 4


class D3D12_BARRIER_LAYOUT(IntFlag):
    D3D12_BARRIER_LAYOUT_UNDEFINED = -1
    D3D12_BARRIER_LAYOUT_COMMON = 0
    D3D12_BARRIER_LAYOUT_PRESENT = 0
    D3D12_BARRIER_LAYOUT_GENERIC_READ = 1
    D3D12_BARRIER_LAYOUT_RENDER_TARGET = 2
    D3D12_BARRIER_LAYOUT_UNORDERED_ACCESS = 3
    D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_WRITE = 4
    D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_READ = 5
    D3D12_BARRIER_LAYOUT_SHADER_RESOURCE = 6
    D3D12_BARRIER_LAYOUT_COPY_SOURCE = 7
    D3D12_BARRIER_LAYOUT_COPY_DEST = 8
    D3D12_BARRIER_LAYOUT_RESOLVE_SOURCE = 9
    D3D12_BARRIER_LAYOUT_RESOLVE_DEST = 10
    D3D12_BARRIER_LAYOUT_SHADING_RATE_SOURCE = 11
    D3D12_BARRIER_LAYOUT_VIDEO_DECODE_READ = 12
    D3D12_BARRIER_LAYOUT_VIDEO_DECODE_WRITE = 13
    D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_READ = 14
    D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_WRITE = 15
    D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_READ = 16
    D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_WRITE = 17
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COMMON = 18
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_GENERIC_READ = 19
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_UNORDERED_ACCESS = 20
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_SHADER_RESOURCE = 21
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_SOURCE = 22
    D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_DEST = 23
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COMMON = 24
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_GENERIC_READ = 25
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_UNORDERED_ACCESS = 26
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_SHADER_RESOURCE = 27
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_SOURCE = 28
    D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_DEST = 29
    D3D12_BARRIER_LAYOUT_VIDEO_QUEUE_COMMON = 30


class D3D12_TEXTURE_COPY_TYPE(IntFlag):
    D3D12_TEXTURE_COPY_TYPE_SUBRESOURCE_INDEX = 0
    D3D12_TEXTURE_COPY_TYPE_PLACED_FOOTPRINT = 1


class D3D12_RESIDENCY_FLAGS(IntFlag):
    D3D12_RESIDENCY_FLAG_NONE = 0
    D3D12_RESIDENCY_FLAG_DENY_OVERBUDGET = 1


class D3D12_COMMAND_LIST_FLAGS(IntFlag):
    D3D12_COMMAND_LIST_FLAG_NONE = 0


class D3D12_LIFETIME_STATE(IntFlag):
    D3D12_LIFETIME_STATE_IN_USE = 0
    D3D12_LIFETIME_STATE_NOT_IN_USE = 1


class D3D12_RESOURCE_BARRIER_TYPE(IntFlag):
    D3D12_RESOURCE_BARRIER_TYPE_TRANSITION = 0
    D3D12_RESOURCE_BARRIER_TYPE_ALIASING = 1
    D3D12_RESOURCE_BARRIER_TYPE_UAV = 2


class D3D12_RESOURCE_BARRIER_FLAGS(IntFlag):
    D3D12_RESOURCE_BARRIER_FLAG_NONE = 0
    D3D12_RESOURCE_BARRIER_FLAG_BEGIN_ONLY = 1
    D3D12_RESOURCE_BARRIER_FLAG_END_ONLY = 2


class D3D12_GRAPHICS_STATES(IntFlag):
    D3D12_GRAPHICS_STATE_NONE = 0
    D3D12_GRAPHICS_STATE_IA_VERTEX_BUFFERS = 1
    D3D12_GRAPHICS_STATE_IA_INDEX_BUFFER = 2
    D3D12_GRAPHICS_STATE_IA_PRIMITIVE_TOPOLOGY = 4
    D3D12_GRAPHICS_STATE_DESCRIPTOR_HEAP = 8
    D3D12_GRAPHICS_STATE_GRAPHICS_ROOT_SIGNATURE = 16
    D3D12_GRAPHICS_STATE_COMPUTE_ROOT_SIGNATURE = 32
    D3D12_GRAPHICS_STATE_RS_VIEWPORTS = 64
    D3D12_GRAPHICS_STATE_RS_SCISSOR_RECTS = 128
    D3D12_GRAPHICS_STATE_PREDICATION = 256
    D3D12_GRAPHICS_STATE_OM_RENDER_TARGETS = 512
    D3D12_GRAPHICS_STATE_OM_STENCIL_REF = 1024
    D3D12_GRAPHICS_STATE_OM_BLEND_FACTOR = 2048
    D3D12_GRAPHICS_STATE_PIPELINE_STATE = 4096
    D3D12_GRAPHICS_STATE_SO_TARGETS = 8192
    D3D12_GRAPHICS_STATE_OM_DEPTH_BOUNDS = 16384
    D3D12_GRAPHICS_STATE_SAMPLE_POSITIONS = 32768
    D3D12_GRAPHICS_STATE_VIEW_INSTANCE_MASK = 65536


class D3D12_META_COMMAND_PARAMETER_TYPE(IntFlag):
    D3D12_META_COMMAND_PARAMETER_TYPE_FLOAT = 0
    D3D12_META_COMMAND_PARAMETER_TYPE_UINT64 = 1
    D3D12_META_COMMAND_PARAMETER_TYPE_GPU_VIRTUAL_ADDRESS = 2
    D3D12_META_COMMAND_PARAMETER_TYPE_CPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV = 3
    D3D12_META_COMMAND_PARAMETER_TYPE_GPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV = 4


class D3D12_META_COMMAND_PARAMETER_FLAGS(IntFlag):
    D3D12_META_COMMAND_PARAMETER_FLAG_INPUT = 1
    D3D12_META_COMMAND_PARAMETER_FLAG_OUTPUT = 2


class D3D12_STATE_OBJECT_TYPE(IntFlag):
    D3D12_STATE_OBJECT_TYPE_COLLECTION = 0
    D3D12_STATE_OBJECT_TYPE_RAYTRACING_PIPELINE = 3


class D3D12_STATE_SUBOBJECT_TYPE(IntFlag):
    D3D12_STATE_SUBOBJECT_TYPE_STATE_OBJECT_CONFIG = 0
    D3D12_STATE_SUBOBJECT_TYPE_GLOBAL_ROOT_SIGNATURE = 1
    D3D12_STATE_SUBOBJECT_TYPE_LOCAL_ROOT_SIGNATURE = 2
    D3D12_STATE_SUBOBJECT_TYPE_NODE_MASK = 3
    D3D12_STATE_SUBOBJECT_TYPE_DXIL_LIBRARY = 5
    D3D12_STATE_SUBOBJECT_TYPE_EXISTING_COLLECTION = 6
    D3D12_STATE_SUBOBJECT_TYPE_SUBOBJECT_TO_EXPORTS_ASSOCIATION = 7
    D3D12_STATE_SUBOBJECT_TYPE_DXIL_SUBOBJECT_TO_EXPORTS_ASSOCIATION = 8
    D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_SHADER_CONFIG = 9
    D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG = 10
    D3D12_STATE_SUBOBJECT_TYPE_HIT_GROUP = 11
    D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG1 = 12
    D3D12_STATE_SUBOBJECT_TYPE_MAX_VALID = 13


class D3D12_SERIALIZED_DATA_TYPE(IntFlag):
    D3D12_SERIALIZED_DATA_RAYTRACING_ACCELERATION_STRUCTURE = 0


class D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS(IntFlag):
    D3D12_DRIVER_MATCHING_IDENTIFIER_COMPATIBLE_WITH_DEVICE = 0
    D3D12_DRIVER_MATCHING_IDENTIFIER_UNSUPPORTED_TYPE = 1
    D3D12_DRIVER_MATCHING_IDENTIFIER_UNRECOGNIZED = 2
    D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_VERSION = 3
    D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_TYPE = 4


class D3D12_RAYTRACING_GEOMETRY_TYPE(IntFlag):
    D3D12_RAYTRACING_GEOMETRY_TYPE_TRIANGLES = 0
    D3D12_RAYTRACING_GEOMETRY_TYPE_PROCEDURAL_PRIMITIVE_AABBS = 1


class D3D12_RAYTRACING_GEOMETRY_FLAGS(IntFlag):
    D3D12_RAYTRACING_GEOMETRY_FLAG_NONE = 0
    D3D12_RAYTRACING_GEOMETRY_FLAG_OPAQUE = 1
    D3D12_RAYTRACING_GEOMETRY_FLAG_NO_DUPLICATE_ANYHIT_INVOCATION = 2


class D3D12_BACKGROUND_PROCESSING_MODE(IntFlag):
    D3D12_BACKGROUND_PROCESSING_MODE_ALLOWED = 0
    D3D12_BACKGROUND_PROCESSING_MODE_ALLOW_INTRUSIVE_MEASUREMENTS = 1
    D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_BACKGROUND_WORK = 2
    D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_PROFILING_BY_SYSTEM = 3


__all__ = [
    'D3D12_SHADING_RATE_2X2', 'D3D12_DESCRIPTOR_HEAP_DESC',
    'D3D12_FILTER_COMPARISON_MIN_POINT_MAG_MIP_LINEAR',
    'D3D12_CLEAR_FLAG_STENCIL',
    'D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_GENERIC_READ',
    'D3D12_BUFFER_SRV_FLAGS', 'D3D12_FILTER_MIN_MAG_MIP_LINEAR',
    'D3D12_RANGE', 'D3D12_BARRIER_LAYOUT_COMMON',
    'D3D12_PREDICATION_OP_EQUAL_ZERO',
    'D3D_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST',
    'D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_EXTENSION_COMMAND',
    'D3D12_AUTO_BREADCRUMB_OP_BEGINSUBMISSION',
    'D3D12_FILTER_MAXIMUM_ANISOTROPIC',
    'D3D11_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST',
    'D3D12_FEATURE_QUERY_META_COMMAND', 'D3D12_TEX2DMS_ARRAY_RTV',
    'D3D12_QUERY_TYPE_PIPELINE_STATISTICS1',
    'DXGI_FORMAT_R16G16_TYPELESS', 'D3D12_BARRIER_LAYOUT_PRESENT',
    'D3D12_FEATURE_ROOT_SIGNATURE',
    'D3D12_RESOURCE_BARRIER_FLAG_BEGIN_ONLY',
    'D3D12_AUTO_BREADCRUMB_OP', 'D3D12_PRIMITIVE_TOPOLOGY_TYPE',
    'D3D12_SHADING_RATE',
    'D3D12_ROOT_SIGNATURE_FLAG_ALLOW_STREAM_OUTPUT',
    'D3D12_ROOT_DESCRIPTOR1', 'D3D12_COMMAND_SIGNATURE_DESC',
    'D3D12_BUFFER_UAV_FLAGS',
    '__MIDL___MIDL_itf_d3d12_0000_0003_0001', 'ID3D12Device3',
    'D3D11_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST',
    'D3D12_SHADING_RATE_1X1', 'DXGI_FORMAT_R8G8B8A8_UINT',
    'D3D12_RAYTRACING_GEOMETRY_AABBS_DESC',
    '__MIDL___MIDL_itf_d3d12_0000_0003_0005',
    'D3D12_QUERY_HEAP_TYPE_SO_STATISTICS', 'D3D12_PACKED_MIP_INFO',
    'D3D12_ROOT_SIGNATURE_FLAG_DENY_MESH_SHADER_ROOT_ACCESS',
    'D3D11_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST',
    'D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_SUBRESOURCE_PARAMETERS',
    'D3D_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_CURRENT_SIZE',
    'D3D12_VIEWPORT', 'DXGI_FORMAT_R16_FLOAT',
    'D3D10_PRIMITIVE_TOPOLOGY_POINTLIST',
    'D3D12_INDIRECT_ARGUMENT_TYPE_INDEX_BUFFER_VIEW',
    'D3D12_PIPELINE_STATE_FLAGS', 'DXGI_FORMAT_R32G8X24_TYPELESS',
    'D3D12_FILTER_MIN_MAG_MIP_POINT', 'DXGI_FORMAT_R8G8B8A8_TYPELESS',
    'D3D10_PRIMITIVE_TOPOLOGY_LINELIST', 'D3D12_HEAP_DESC',
    'D3D12_META_COMMAND_PARAMETER_TYPE',
    'D3D12_ROOT_SIGNATURE_FLAG_CBV_SRV_UAV_HEAP_DIRECTLY_INDEXED',
    'D3D12_FILTER_COMPARISON_MIN_MAG_LINEAR_MIP_POINT',
    'ID3D12CommandList', 'D3D12_CONSERVATIVE_RASTERIZATION_MODE_OFF',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_COMPACTION',
    'D3D12_RESOLVE_MODE_MAX', 'D3D12_HEAP_PROPERTIES',
    'DXGI_SAMPLE_DESC', 'D3D12_DESCRIPTOR_RANGE_TYPE_SAMPLER',
    'D3D12_RESOURCE_DESC1', 'D3D12_RTV_DIMENSION_BUFFER',
    'D3D12_BLEND_INV_DEST_COLOR',
    'D3D12_DESCRIPTOR_HEAP_TYPE_NUM_TYPES',
    'D3D12_PROTECTED_SESSION_STATUS_INVALID',
    'D3D12_RENDER_PASS_FLAG_ALLOW_UAV_WRITES',
    'DXGI_FORMAT_R16G16B16A16_SNORM', 'D3D12_RESOURCE_DIMENSION',
    'D3D12_DESCRIPTOR_HEAP_TYPE_RTV',
    'D3D12_RESOURCE_STATE_VIDEO_DECODE_WRITE',
    'D3D12_RENDER_PASS_DEPTH_STENCIL_DESC',
    'D3D12_DSV_DIMENSION_TEXTURE2DARRAY',
    'D3D12_ROOT_DESCRIPTOR_FLAG_DATA_VOLATILE',
    'D3D12_HEAP_TYPE_READBACK',
    'D3D_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST',
    'D3D12_PROTECTED_SESSION_STATUS',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_VISUALIZATION_DECODE_FOR_TOOLS',
    'D3D12_FEATURE_ARCHITECTURE1',
    'D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ',
    'D3D12_BLEND_SRC1_ALPHA', 'D3D12_STATE_OBJECT_TYPE',
    'D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_DISCARD',
    'D3D12_AUTO_BREADCRUMB_OP_INITIALIZEMETACOMMAND',
    'D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT', 'D3D12_ROOT_CONSTANTS',
    'D3D12_COMPARISON_FUNC_ALWAYS',
    'D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_WRITE',
    'D3D12_SRV_DIMENSION_RAYTRACING_ACCELERATION_STRUCTURE',
    'ID3D12GraphicsCommandList',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_VECTOR_HEAP',
    'D3D12_DRED_ALLOCATION_TYPE_COMMAND_LIST',
    'D3D12_DRED_ALLOCATION_TYPE_DESCRIPTOR_HEAP',
    'D3D12_RESIDENCY_FLAG_NONE', 'D3D12_TEX2D_RTV',
    'D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT64',
    'D3D12_ROOT_PARAMETER',
    'D3D12_AUTO_BREADCRUMB_OP_DRAWINDEXEDINSTANCED',
    'D3D12_FILTER_COMPARISON_MIN_POINT_MAG_LINEAR_MIP_POINT',
    'ID3D12ProtectedResourceSession', 'D3D12_INDEX_BUFFER_VIEW',
    'D3D12_GRAPHICS_STATES', 'D3D12_GRAPHICS_STATE_NONE',
    'D3D12_LOGIC_OP_SET', 'D3D12_COMPARISON_FUNC_NOT_EQUAL',
    'DXGI_FORMAT_R8G8_SINT',
    'D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_PRESERVE',
    'D3D12_HEAP_FLAG_ALLOW_ALL_BUFFERS_AND_TEXTURES',
    'D3D12_STATE_SUBOBJECT_TYPE_STATE_OBJECT_CONFIG',
    'D3D12_ROOT_SIGNATURE_FLAG_DENY_PIXEL_SHADER_ROOT_ACCESS',
    'DXGI_FORMAT_SAMPLER_FEEDBACK_MIP_REGION_USED_OPAQUE',
    'D3D12_CPU_PAGE_PROPERTY',
    'D3D12_CPU_PAGE_PROPERTY_WRITE_COMBINE',
    'D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP', 'D3D12_TEXTURE_COPY_TYPE',
    'D3D12_QUERY_HEAP_TYPE',
    'D3D12_SHADER_CACHE_CONTROL_FLAG_DISABLE',
    'D3D12_FILTER_MAXIMUM_MIN_MAG_POINT_MIP_LINEAR',
    'D3D12_RENDER_PASS_BEGINNING_ACCESS',
    'D3D12_GPU_VIRTUAL_ADDRESS_AND_STRIDE',
    'D3D12_RAYTRACING_GEOMETRY_FLAGS', 'D3D12_BLEND_BLEND_FACTOR',
    'D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_BACKGROUND_WORK',
    'D3D12_QUERY_TYPE_VIDEO_DECODE_STATISTICS',
    'D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CONVERSIONS',
    'D3D12_COMMAND_LIST_TYPE_VIDEO_DECODE',
    'D3D12_RESOURCE_STATE_VIDEO_ENCODE_READ',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TOOLS_VISUALIZATION',
    'D3D12_STATIC_BORDER_COLOR_OPAQUE_BLACK',
    'D3D_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST',
    'D3D12_TEXTURE_LAYOUT', 'D3D12_SHADER_VISIBILITY_PIXEL',
    'D3D11_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST',
    'D3D12_SHADING_RATE_COMBINER_MAX',
    'D3D12_AUTO_BREADCRUMB_OP_WRITEBUFFERIMMEDIATE',
    'DXGI_FORMAT_B8G8R8X8_UNORM',
    'D3D_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST',
    'D3D12_RESOURCE_UAV_BARRIER',
    'D3D12_PROTECTED_RESOURCE_SESSION_FLAGS',
    'D3D12_FEATURE_D3D12_OPTIONS8', 'D3D12_DEPTH_STENCIL_DESC',
    'D3D12_INDIRECT_ARGUMENT_TYPE_DRAW', 'DXGI_FORMAT_R8G8B8A8_SNORM',
    'D3D12_RTV_DIMENSION_UNKNOWN', 'D3D12_SRV_DIMENSION_UNKNOWN',
    'D3D12_META_COMMAND_PARAMETER_TYPE_GPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV',
    'DXGI_FORMAT_R8G8_B8G8_UNORM', 'D3D12_RESOURCE_DESC',
    'D3D12_RESOURCE_DIMENSION_TEXTURE1D',
    'D3D12_FEATURE_D3D12_OPTIONS9', 'DXGI_FORMAT_R8_SINT',
    'ID3D12ShaderCacheSession', 'D3D12_TILE_MAPPING_FLAG_NONE',
    'D3D12_RENDER_PASS_FLAG_RESUMING_PASS',
    'D3D12_FILTER_MINIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT',
    'D3D_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST',
    'D3D12_HEAP_TYPE_CUSTOM', 'D3D12_BARRIER_LAYOUT_UNORDERED_ACCESS',
    'D3D12_RESOURCE_ALLOCATION_INFO',
    'ID3D12DeviceRemovedExtendedData1',
    'D3D_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST',
    'D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_UNORDERED_ACCESS',
    'DXGI_FORMAT_A8P8', 'ID3D12GraphicsCommandList5',
    'D3D12_FILTER_COMPARISON_MIN_MAG_MIP_POINT',
    'D3D11_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST',
    'D3D12_DESCRIPTOR_HEAP_TYPE_CBV_SRV_UAV', 'D3D12_CULL_MODE_FRONT',
    'D3D12_TILE_MAPPING_FLAG_NO_HAZARD',
    'D3D12_ROOT_PARAMETER_TYPE_SRV',
    'D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_MIP_POINT',
    'D3D12_TEXTURE_ADDRESS_MODE',
    'D3D12_DESCRIPTOR_HEAP_TYPE_SAMPLER', 'DXGI_FORMAT_V208',
    'D3D12_MULTIPLE_FENCE_WAIT_FLAG_ANY', 'D3D12_BLEND_ALPHA_FACTOR',
    'D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_STATIC_KEEPING_BUFFER_BOUNDS_CHECKS',
    'DXGI_FORMAT_P8', 'D3D12_DSV_FLAG_READ_ONLY_STENCIL',
    'D3D12_FILTER_MINIMUM_MIN_MAG_MIP_LINEAR',
    'D3D_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST',
    'ID3D12GraphicsCommandList1',
    'D3D12_RESOURCE_BARRIER_TYPE_ALIASING',
    'D3D12_STATIC_SAMPLER_DESC',
    'D3D12_TEXTURE_COPY_TYPE_SUBRESOURCE_INDEX',
    'D3D12_TEXTURE_COPY_TYPE_PLACED_FOOTPRINT',
    'DXGI_FORMAT_R9G9B9E5_SHAREDEXP',
    'D3D12_TEXTURE_ADDRESS_MODE_MIRROR',
    'D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH',
    'D3D12_MULTIPLE_FENCE_WAIT_FLAG_ALL',
    'D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_TYPE',
    'D3D12_TEX3D_RTV', 'DXGI_FORMAT_BC1_UNORM',
    'D3D12_RESIDENCY_FLAG_DENY_OVERBUDGET',
    'D3D12_RENDER_TARGET_BLEND_DESC', 'DXGI_FORMAT_R32_TYPELESS',
    'DXGI_FORMAT_BC4_UNORM', 'DXGI_FORMAT_R32_UINT',
    'D3D12_QUERY_TYPE_SO_STATISTICS_STREAM1',
    'D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ',
    'D3D12_DRED_ALLOCATION_NODE1', 'DXGI_FORMAT_R1_UNORM',
    'D3D12_TEX1D_RTV', 'D3D12_STENCIL_OP_DECR_SAT',
    'D3D12_COMPARISON_FUNC', 'D3D12_BLEND_INV_SRC_ALPHA',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_MOTION_ESTIMATOR',
    'D3D11_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST',
    'D3D12_GRAPHICS_STATE_SAMPLE_POSITIONS',
    'D3D12_SHADER_CACHE_MODE',
    'D3D12_FILTER_MINIMUM_MIN_MAG_POINT_MIP_LINEAR',
    'D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCE',
    'D3D12_RENDER_PASS_ENDING_ACCESS',
    'D3D12_RESOURCE_TRANSITION_BARRIER',
    'D3D12_DESCRIPTOR_RANGE_FLAGS',
    'D3D12_RESOURCE_STATE_DEPTH_WRITE', 'D3D12_TEX2DMS_ARRAY_DSV',
    'D3D12_BLEND', 'D3D_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST',
    'D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COMMON',
    'D3D12_RESOURCE_STATE_PREDICATION',
    'D3D12_UAV_DIMENSION_TEXTURE1DARRAY',
    'D3D_ROOT_SIGNATURE_VERSION_1',
    'D3D12_AUTO_BREADCRUMB_OP_DISPATCH',
    'D3D12_RESOURCE_STATE_VIDEO_PROCESS_WRITE',
    'DXGI_FORMAT_BC5_SNORM',
    'D3D12_RESOURCE_FLAG_ALLOW_CROSS_ADAPTER',
    'D3D12_INDIRECT_ARGUMENT_TYPE_SHADER_RESOURCE_VIEW',
    'D3D12_DRED_ALLOCATION_TYPE_QUERY_HEAP',
    'D3D12_COMPARISON_FUNC_GREATER_EQUAL',
    'D3D12_FILTER_MIN_POINT_MAG_MIP_LINEAR',
    'D3D11_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST',
    'D3D12_PRIMITIVE_TOPOLOGY_TYPE_POINT',
    'D3D12_LOGIC_OP_AND_INVERTED', 'D3D12_BUFFER_SRV_FLAG_RAW',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_ALLOW_UPDATE',
    'D3D12_TEX1D_DSV', 'D3D12_LOGIC_OP_AND_REVERSE',
    'D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_SOURCE',
    'D3D12_TEX2D_DSV',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_SERIALIZE',
    'DXGI_FORMAT_Y216', 'D3D12_DRED_ALLOCATION_NODE',
    'DXGI_FORMAT_R16_TYPELESS', 'DXGI_FORMAT_R32G32_SINT',
    'D3D12_AUTO_BREADCRUMB_OP_BEGINEVENT',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0005',
    'D3D12_ROOT_PARAMETER_TYPE_UAV',
    'D3D_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAGS',
    'D3D12_BLEND_SRC1_COLOR', 'ID3D12Device9',
    'D3D12_DRED_ALLOCATION_TYPE_STATE_OBJECT',
    'D3D12_GRAPHICS_STATE_PREDICATION',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER',
    'D3D12_STATE_SUBOBJECT_TYPE_MAX_VALID',
    'DXGI_FORMAT_BC7_UNORM_SRGB', 'D3D12_DESCRIPTOR_RANGE_TYPE_SRV',
    'D3D12_RASTERIZER_DESC', 'DXGI_FORMAT_BC2_TYPELESS',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_TOP_LEVEL',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0002',
    'D3D12_QUERY_HEAP_TYPE_OCCLUSION', 'D3D12_RESOURCE_BARRIER',
    'D3D12_INDIRECT_ARGUMENT_TYPE_VERTEX_BUFFER_VIEW',
    'D3D12_QUERY_TYPE_BINARY_OCCLUSION',
    'D3D_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST',
    'DXGI_FORMAT_P010', 'DXGI_FORMAT_R16G16_UNORM',
    'DXGI_FORMAT_AYUV', 'D3D12_GRAPHICS_STATE_RS_VIEWPORTS',
    'D3D12_FEATURE_FORMAT_SUPPORT', 'D3D12_FEATURE_D3D12_OPTIONS5',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE_BOTTOM_LEVEL',
    'D3D_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST',
    'DXGI_FORMAT_R32G32B32A32_TYPELESS',
    'D3D12_AUTO_BREADCRUMB_OP_SETMARKER',
    'D3D_PRIMITIVE_TOPOLOGY_LINELIST',
    'D3D12_META_COMMAND_PARAMETER_STAGE_EXECUTION',
    'D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_RESOLVE',
    'D3D12_HEAP_FLAG_SHARED', 'D3D12_ROOT_SIGNATURE_DESC1',
    'D3D12_DESCRIPTOR_HEAP_FLAGS', 'Library',
    'DXGI_FORMAT_G8R8_G8B8_UNORM',
    'DXGI_FORMAT_R10G10B10_XR_BIAS_A2_UNORM',
    'D3D12_FILTER_MAXIMUM_MIN_MAG_LINEAR_MIP_POINT',
    'D3D12_STENCIL_OP_INVERT', 'D3D12_ROOT_DESCRIPTOR_TABLE1',
    'D3D12_HEAP_FLAG_NONE', 'D3D12_FENCE_FLAG_SHARED_CROSS_ADAPTER',
    'D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_D3D_CACHE_FOR_DRIVER',
    'D3D12_BACKGROUND_PROCESSING_MODE',
    'D3D12_AUTO_BREADCRUMB_OP_ENDEVENT',
    'D3D12_SUBRESOURCE_RANGE_UINT64', 'D3D12_BOX',
    'D3D12_RENDER_PASS_ENDING_ACCESS_RESOLVE_PARAMETERS',
    'D3D12_TEXTURE_ADDRESS_MODE_MIRROR_ONCE',
    'D3D12_TEXTURE_ADDRESS_MODE_WRAP',
    'D3D12_GPU_VIRTUAL_ADDRESS_RANGE',
    'D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_SHADER_RESOURCE',
    'D3D12_ROOT_SIGNATURE_FLAG_DENY_GEOMETRY_SHADER_ROOT_ACCESS',
    'D3D12_SHADER_CACHE_FLAG_DRIVER_VERSIONED',
    'D3D12_STENCIL_OP_ZERO', 'DXGI_FORMAT_R8G8_SNORM',
    'D3D12_FEATURE_SHADER_CACHE', 'DXGI_FORMAT_BC2_UNORM',
    'DXGI_FORMAT_IA44', 'D3D12_RENDER_PASS_FLAGS',
    'D3D12_CLEAR_FLAGS',
    'D3D12_DRED_ALLOCATION_TYPE_PROTECTEDRESOURCESESSION',
    'D3D12_SHADER_VISIBILITY_VERTEX', 'D3D12_HEAP_TYPE_UPLOAD',
    'D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_SHADER_RESOURCE',
    'D3D_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST',
    'D3D_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST',
    'D3D_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST',
    'D3D12_DSV_DIMENSION_TEXTURE2D',
    'D3D12_PREDICATION_OP_NOT_EQUAL_ZERO', 'D3D12_STATE_OBJECT_DESC',
    'D3D12_SHADER_CACHE_MODE_MEMORY',
    'D3D12_DRIVER_MATCHING_IDENTIFIER_STATUS',
    'D3D12_TEXTURE_COPY_LOCATION',
    'D3D12_SRV_DIMENSION_TEXTURE2DARRAY',
    'DXGI_FORMAT_B8G8R8X8_TYPELESS', 'D3D12_RESOLVE_MODE_MIN',
    'DXGI_FORMAT_BC6H_TYPELESS', 'D3D12_FILL_MODE_SOLID',
    'D3D12_COMMAND_LIST_TYPE_COMPUTE', '_SECURITY_ATTRIBUTES',
    'D3D12_UAV_DIMENSION_BUFFER',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0006',
    'D3D12_RENDER_PASS_RENDER_TARGET_DESC',
    'D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_POINT',
    'D3D12_RESOURCE_FLAG_NONE',
    'D3D12_INDIRECT_ARGUMENT_TYPE_UNORDERED_ACCESS_VIEW',
    'D3D12_DRED_ALLOCATION_TYPE_PIPELINE_LIBRARY',
    'D3D12_DRED_ALLOCATION_TYPE_SCHEDULINGGROUP',
    'D3D12_RESOURCE_STATE_VIDEO_DECODE_READ',
    'D3D12_AUTO_BREADCRUMB_OP_ENDSUBMISSION',
    'D3D12_COMPARISON_FUNC_NEVER',
    'D3D12_PROTECTED_RESOURCE_SESSION_DESC',
    'D3D12_FEATURE_D3D12_OPTIONS12', 'D3D_ROOT_SIGNATURE_VERSION_1_1',
    'DXGI_FORMAT_BC4_TYPELESS',
    'D3D12_FILTER_COMPARISON_MIN_MAG_MIP_LINEAR',
    'D3D12_STENCIL_OP_DECR', 'D3D12_SRV_DIMENSION',
    'D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE',
    'DXGI_FORMAT_R8G8_UNORM',
    'D3D12_RESOURCE_FLAG_ALLOW_UNORDERED_ACCESS',
    'D3D12_RESOURCE_STATE_ALL_SHADER_RESOURCE',
    'D3D12_COMMAND_LIST_TYPE_DIRECT', 'D3D12_FEATURE_D3D12_OPTIONS10',
    'D3D12_RESOURCE_STATE_VIDEO_ENCODE_WRITE',
    'D3D12_FILL_MODE_WIREFRAME', 'DXGI_FORMAT_R16G16B16A16_UINT',
    'D3D12_DESCRIPTOR_RANGE_FLAG_DATA_VOLATILE',
    'D3D12_AUTO_BREADCRUMB_OP_PRESENT', 'DXGI_FORMAT_V408',
    'D3D12_RTV_DIMENSION',
    'D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS1',
    'D3D12_GRAPHICS_STATE_IA_PRIMITIVE_TOPOLOGY',
    'D3D12_FILTER_COMPARISON_MIN_MAG_POINT_MIP_LINEAR',
    'D3D12_SHADING_RATE_2X4', 'ID3D12DeviceChild',
    'D3D12_BARRIER_LAYOUT_VIDEO_QUEUE_COMMON', 'DXGI_FORMAT_AI44',
    'D3D12_RESOURCE_BARRIER_FLAG_END_ONLY', 'D3D12_SHADING_RATE_1X2',
    'DXGI_FORMAT_R10G10B10A2_TYPELESS',
    'D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_POINT_MIP_LINEAR',
    'D3D12_META_COMMAND_DESC', 'D3D12_COMMAND_QUEUE_FLAGS',
    'D3D12_RAYTRACING_GEOMETRY_FLAG_NONE',
    'D3D12_DSV_DIMENSION_TEXTURE1D',
    'D3D12_RESOURCE_DIMENSION_UNKNOWN',
    'D3D12_INPUT_CLASSIFICATION_PER_VERTEX_DATA',
    'D3D12_HEAP_FLAG_ALLOW_ONLY_NON_RT_DS_TEXTURES',
    'D3D12_AUTO_BREADCRUMB_OP_EXECUTEBUNDLE', 'D3D12_LOGIC_OP_OR',
    'ID3D12Heap', 'D3D12_BLEND_DEST_COLOR',
    'D3D12_RTV_DIMENSION_TEXTURE2D', 'DXGI_FORMAT_R16_UNORM',
    'D3D12_SHADER_VISIBILITY_MESH',
    'D3D12_AUTO_BREADCRUMB_OP_RESOURCEBARRIER',
    'D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_PRESERVE',
    'D3D12_HEAP_FLAG_CREATE_NOT_RESIDENT',
    'DXGI_FORMAT_R8G8B8A8_UNORM',
    'D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_DEST',
    'D3D12_BLEND_INV_SRC_COLOR',
    'D3D12_FILTER_COMPARISON_MIN_LINEAR_MAG_MIP_POINT',
    'D3D12_DRED_ALLOCATION_TYPE_FENCE',
    'D3D12_GRAPHICS_STATE_OM_DEPTH_BOUNDS',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE',
    'D3D12_SHADING_RATE_2X1', 'D3D12_FEATURE_FEATURE_LEVELS',
    'D3D12_AUTO_BREADCRUMB_OP_SETPIPELINESTATE1',
    'D3D11_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST',
    'D3D12_ROOT_DESCRIPTOR_TABLE', 'D3D12_TEX1D_ARRAY_DSV',
    'D3D12_DRED_PAGE_FAULT_OUTPUT',
    'D3D11_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST',
    'D3D12_RENDER_PASS_FLAG_NONE',
    'D3D12_RESOURCE_STATE_RENDER_TARGET', 'ID3D12Device2',
    'D3D12_GRAPHICS_STATE_RS_SCISSOR_RECTS',
    'D3D12_STATE_OBJECT_TYPE_COLLECTION',
    'D3D12_FEATURE_ARCHITECTURE', 'DXGI_FORMAT_P016',
    'D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES',
    'D3D12_STATE_SUBOBJECT_TYPE_SUBOBJECT_TO_EXPORTS_ASSOCIATION',
    'D3D12_DRED_ALLOCATION_TYPE_INVALID',
    'D3D12_DRED_ALLOCATION_TYPE_COMMAND_SIGNATURE', 'typelib_path',
    'D3D12_TILE_RANGE_FLAG_NONE', 'D3D12_FILTER_MINIMUM_ANISOTROPIC',
    'D3D12_TEXTURE_LAYOUT_UNKNOWN', 'DXGI_FORMAT_D16_UNORM',
    'DXGI_FORMAT_R16_SNORM',
    'D3D12_GRAPHICS_STATE_COMPUTE_ROOT_SIGNATURE',
    'D3D12_STATE_SUBOBJECT_TYPE_GLOBAL_ROOT_SIGNATURE',
    'D3D12_SHADER_CACHE_MODE_DISK',
    'ID3D12DeviceRemovedExtendedDataSettings',
    'D3D12_STATE_SUBOBJECT_TYPE_DXIL_LIBRARY',
    'D3D12_DRED_ALLOCATION_TYPE_COMMAND_ALLOCATOR',
    'ID3D12RootSignature', 'D3D12_RTV_DIMENSION_TEXTURE2DARRAY',
    'D3D11_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST',
    'D3D12_FEATURE',
    'D3D12_STATE_SUBOBJECT_TYPE_DXIL_SUBOBJECT_TO_EXPORTS_ASSOCIATION',
    'D3D12_RENDER_PASS_FLAG_SUSPENDING_PASS', 'ID3D12QueryHeap',
    'D3D12_RESOLVE_MODE_ENCODE_SAMPLER_FEEDBACK', 'D3D12_TEX2DMS_DSV',
    'D3D12_CPU_PAGE_PROPERTY_UNKNOWN',
    '__MIDL___MIDL_itf_d3d12_0000_0034_0002',
    'D3D12_GPU_DESCRIPTOR_HANDLE',
    'D3D11_PRIMITIVE_TOPOLOGY_LINELIST_ADJ',
    'D3D12_BUFFER_SRV_FLAG_NONE', 'D3D12_SHADER_CACHE_SESSION_DESC',
    'D3D12_COMPARISON_FUNC_EQUAL',
    'D3D12_AUTO_BREADCRUMB_OP_EXECUTEEXTENSIONCOMMAND',
    'D3D11_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST',
    'D3D12_TILE_COPY_FLAG_NONE', 'D3D12_TEX1D_UAV',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_NONE',
    'D3D12_BARRIER_LAYOUT_SHADER_RESOURCE',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0010',
    'DXGI_FORMAT_R8G8_TYPELESS', 'D3D12_FEATURE_D3D12_OPTIONS1',
    'D3D12_AUTO_BREADCRUMB_OP_DRAWINSTANCED',
    'D3D12_RENDER_PASS_ENDING_ACCESS_TYPE_NO_ACCESS',
    'D3D12_TILE_REGION_SIZE',
    'D3D12_AUTO_BREADCRUMB_OP_INITIALIZEEXTENSIONCOMMAND',
    'DXGI_FORMAT_R8_SNORM',
    'D3D_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST',
    'D3D12_MEMORY_POOL_L0',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_DESERIALIZE',
    'D3D12_STENCIL_OP', 'D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT',
    'D3D12_RTV_DIMENSION_TEXTURE1DARRAY',
    'D3D12_HEAP_FLAG_DENY_NON_RT_DS_TEXTURES', 'D3D12_FENCE_FLAGS',
    'D3D12_LOGIC_OP_COPY_INVERTED', 'DXGI_FORMAT_R8G8B8A8_SINT',
    'D3D12_AUTO_BREADCRUMB_OP_RESOLVEQUERYDATA',
    'D3D_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST',
    'D3D12_FENCE_FLAG_NON_MONITORED',
    'D3D12_INDIRECT_ARGUMENT_TYPE_DRAW_INDEXED',
    'D3D12_SERIALIZED_DATA_DRIVER_MATCHING_IDENTIFIER',
    'D3D12_HEAP_FLAG_HARDWARE_PROTECTED',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_TRACE',
    'D3D12_FILTER', 'D3D12_META_COMMAND_PARAMETER_FLAGS',
    'D3D12_BLEND_OP_MAX', 'D3D12_COMMAND_LIST_TYPE_COPY',
    'D3D12_FILTER_MINIMUM_MIN_MAG_LINEAR_MIP_POINT',
    'D3D12_TEX3D_UAV', 'D3D12_META_COMMAND_PARAMETER_FLAG_OUTPUT',
    'D3D12_FEATURE_MULTISAMPLE_QUALITY_LEVELS',
    'D3D12_RESOURCE_STATE_PIXEL_SHADER_RESOURCE', 'D3D12_TEX1D_SRV',
    'DXGI_FORMAT_D32_FLOAT', 'DXGI_FORMAT_B8G8R8A8_UNORM',
    'D3D12_DRED_ALLOCATION_TYPE_COMMAND_RECORDER',
    'D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_SUPPORT',
    'D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ',
    'D3D12_DESCRIPTOR_RANGE_TYPE', 'DXGI_FORMAT_BC3_UNORM',
    'D3D12_BLEND_ZERO', 'D3D12_TEXCUBE_SRV',
    'DXGI_FORMAT_B5G6R5_UNORM', 'DXGI_FORMAT_P208',
    'D3D12_RESOURCE_STATE_PRESENT', 'D3D12_TEX2D_ARRAY_DSV',
    'D3D12_AUTO_BREADCRUMB_OP_COPYTILES',
    'D3D12_WRITEBUFFERIMMEDIATE_MODE_DEFAULT',
    'D3D11_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST',
    'D3D12_LIFETIME_STATE_NOT_IN_USE',
    'D3D_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST',
    'D3D12_TILE_SHAPE',
    'D3D12_RESOURCE_STATE_RAYTRACING_ACCELERATION_STRUCTURE',
    'ID3D12Device1', 'D3D12_DSV_FLAG_READ_ONLY_DEPTH',
    'D3D12_FILTER_MIN_MAG_POINT_MIP_LINEAR',
    'D3D11_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST',
    'D3D12_TEX2DMS_ARRAY_SRV',
    'D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC',
    'D3D12_RESOURCE_FLAG_ALLOW_SIMULTANEOUS_ACCESS',
    'D3D10_PRIMITIVE_TOPOLOGY_UNDEFINED',
    'D3D12_SHADING_RATE_COMBINER_MIN', 'D3D12_SAMPLE_POSITION',
    'D3D12_BLEND_INV_BLEND_FACTOR', 'DXGI_FORMAT',
    'D3D12_FILTER_MINIMUM_MIN_POINT_MAG_MIP_LINEAR',
    'D3D12_QUERY_HEAP_TYPE_PIPELINE_STATISTICS',
    'DXGI_FORMAT_R8G8_UINT', 'D3D12_SHADER_CACHE_FLAGS',
    'D3D12_COMPARISON_FUNC_GREATER',
    'ID3D12VirtualizationGuestDevice',
    'D3D12_CONSERVATIVE_RASTERIZATION_MODE_ON',
    'D3D12_COMMAND_LIST_TYPE_VIDEO_PROCESS', 'D3D12_FENCE_FLAG_NONE',
    'ID3D12Device5',
    'D3D11_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST',
    'DXGI_FORMAT_A8_UNORM', 'D3D12_META_COMMAND_PARAMETER_FLAG_INPUT',
    'D3D12_UNORDERED_ACCESS_VIEW_DESC',
    'D3D12_RENDER_PASS_BEGINNING_ACCESS_CLEAR_PARAMETERS',
    'DXGI_FORMAT_R16_UINT',
    'D3D12_DESCRIPTOR_RANGE_FLAG_DATA_STATIC_WHILE_SET_AT_EXECUTE',
    'D3D12_DRED_PAGE_FAULT_OUTPUT1',
    'D3D12_HEAP_FLAG_ALLOW_SHADER_ATOMICS', 'D3D12_BLEND_DESC',
    'D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR',
    'D3D12_GPU_VIRTUAL_ADDRESS_RANGE_AND_STRIDE',
    'D3D12_AUTO_BREADCRUMB_OP_PROCESSFRAMES1',
    'D3D12_ROOT_DESCRIPTOR_FLAGS',
    'D3D12_RESOURCE_FLAG_ALLOW_RENDER_TARGET',
    'DXGI_FORMAT_R16G16_FLOAT', 'D3D12_BLEND_INV_DEST_ALPHA',
    'D3D12_RESOURCE_FLAG_RAYTRACING_ACCELERATION_STRUCTURE',
    'ID3D12CommandAllocator',
    'D3D12_STATIC_BORDER_COLOR_OPAQUE_WHITE',
    'D3D12_RESOURCE_STATE_COPY_SOURCE',
    'DXGI_FORMAT_X32_TYPELESS_G8X24_UINT',
    'D3D11_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST',
    'D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFFFFFF',
    'D3D12_TILE_COPY_FLAG_SWIZZLED_TILED_RESOURCE_TO_LINEAR_BUFFER',
    'ID3D12PipelineLibrary1',
    'D3D12_RESOURCE_STATE_NON_PIXEL_SHADER_RESOURCE',
    'D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_WRITE',
    'D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST', 'D3D12_BUFFER_SRV',
    'D3D12_DESCRIPTOR_HEAP_FLAG_SHADER_VISIBLE',
    'ID3D12ProtectedSession',
    'D3D12_FILTER_MIN_POINT_MAG_LINEAR_MIP_POINT',
    'D3D12_DRED_ALLOCATION_TYPE', 'DXGI_FORMAT_R32G32B32_TYPELESS',
    'D3D_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST',
    'D3D12_META_COMMAND_PARAMETER_TYPE_UINT64',
    'DXGI_FORMAT_R11G11B10_FLOAT',
    '__MIDL___MIDL_itf_d3d12_0000_0003_0002',
    'D3D12_DSV_DIMENSION_TEXTURE2DMS',
    'D3D_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST',
    'D3D12_RAYTRACING_GEOMETRY_FLAG_OPAQUE',
    'D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME',
    'D3D12_META_COMMAND_PARAMETER_STAGE', 'ID3D12CommandQueue',
    'D3D12_DEPTH_STENCIL_VALUE', 'D3D12_BLEND_ONE',
    'D3D12_CACHED_PIPELINE_STATE',
    'D3D12_SHADER_CACHE_CONTROL_FLAG_CLEAR',
    'ID3D12GraphicsCommandList6', 'D3D12_MULTIPLE_FENCE_WAIT_FLAGS',
    'D3D12_BARRIER_LAYOUT_VIDEO_DECODE_WRITE',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_COMPACTED_SIZE',
    'D3D12_GRAPHICS_STATE_DESCRIPTOR_HEAP', 'D3D12_TILE_RANGE_FLAGS',
    'D3D12_STATE_SUBOBJECT_TYPE', 'D3D12_RESIDENCY_PRIORITY',
    'D3D12_META_COMMAND_PARAMETER_TYPE_GPU_VIRTUAL_ADDRESS',
    'D3D12_RESOURCE_BARRIER_TYPE_TRANSITION',
    'D3D12_SHADER_CACHE_CONTROL_FLAGS',
    'D3D12_CONSERVATIVE_RASTERIZATION_MODE',
    'D3D12_SRV_DIMENSION_TEXTURE3D',
    'D3D12_DRIVER_MATCHING_IDENTIFIER_COMPATIBLE_WITH_DEVICE',
    'DXGI_FORMAT_R32G32_TYPELESS', 'D3D12_BLEND_INV_SRC1_ALPHA',
    'D3D12_DRED_ALLOCATION_TYPE_COMMAND_QUEUE',
    'D3D12_TEX2D_ARRAY_UAV',
    'D3D12_FILTER_MIN_LINEAR_MAG_POINT_MIP_LINEAR',
    'D3D12_GRAPHICS_STATE_IA_INDEX_BUFFER',
    'D3D12_SRV_DIMENSION_TEXTURECUBEARRAY',
    '__MIDL___MIDL_itf_d3d12_0000_0034_0001',
    'D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_LINEAR_MIP_POINT',
    'D3D11_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST',
    'D3D12_MEMORY_POOL_UNKNOWN', 'D3D12_BARRIER_LAYOUT_COPY_SOURCE',
    'ID3D12StateObject', 'D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_0xFFFF',
    'D3D12_TEXTURE_ADDRESS_MODE_CLAMP',
    'D3D12_BLEND_INV_ALPHA_FACTOR', 'DXGI_FORMAT_R16G16B16A16_UNORM',
    'D3D12_STATE_OBJECT_TYPE_RAYTRACING_PIPELINE',
    'D3D12_RESOURCE_STATE_COPY_DEST', 'ID3D12StateObjectProperties',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_TYPE', 'ID3D12Pageable',
    'D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS', 'D3D12_BUFFER_RTV',
    'D3D12_DISPATCH_RAYS_DESC', 'D3D12_DRED_ALLOCATION_TYPE_HEAP',
    'D3D12_FILL_MODE', 'D3D12_RESOURCE_DIMENSION_TEXTURE3D',
    'D3D12_LOGIC_OP_EQUIV', 'D3D12_PRIMITIVE_TOPOLOGY_TYPE_PATCH',
    'D3D12_BARRIER_LAYOUT_SHADING_RATE_SOURCE',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0009',
    'D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_DISCARD',
    'D3D12_RESOURCE_STATE_COMMON',
    'D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_OUT',
    'D3D11_PRIMITIVE_TOPOLOGY_LINELIST',
    'D3D12_DEPTH_WRITE_MASK_ZERO', 'DXGI_FORMAT_R32G32B32A32_UINT',
    'D3D12_BLEND_OP', 'D3D12_AUTO_BREADCRUMB_OP_COPYBUFFERREGION',
    'DXGI_FORMAT_X24_TYPELESS_G8_UINT',
    'D3D12_RESOURCE_DIMENSION_BUFFER',
    'D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ',
    'DXGI_FORMAT_R32G32B32_UINT',
    'D3D12_HEAP_FLAG_DENY_RT_DS_TEXTURES', 'D3D12_ROOT_DESCRIPTOR',
    'D3D12_FEATURE_D3D12_OPTIONS7', 'D3D12_RESOURCE_STATE_DEPTH_READ',
    'D3D12_AUTO_BREADCRUMB_OP_ESTIMATEMOTION',
    'D3D12_INPUT_ELEMENT_DESC',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_TYPE',
    'D3D12_QUERY_TYPE_OCCLUSION',
    'D3D12_QUERY_TYPE_SO_STATISTICS_STREAM0',
    'D3D12_RAYTRACING_GEOMETRY_TYPE_TRIANGLES',
    'D3D12_SRV_DIMENSION_TEXTURE2D',
    'D3D12_TILE_RANGE_FLAG_REUSE_SINGLE_TILE',
    'D3D12_DSV_DIMENSION_TEXTURE2DMSARRAY',
    'D3D12_STATE_SUBOBJECT_TYPE_EXISTING_COLLECTION',
    'D3D12_RESOURCE_STATE_RESOLVE_DEST',
    'D3D12_INDEX_BUFFER_STRIP_CUT_VALUE',
    'D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_CLEAR',
    'D3D12_COMMAND_QUEUE_FLAG_DISABLE_GPU_TIMEOUT',
    'D3D12_CPU_DESCRIPTOR_HANDLE',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_SRV',
    'D3D12_AUTO_BREADCRUMB_OP_SETPROTECTEDRESOURCESESSION',
    'D3D12_COMPUTE_PIPELINE_STATE_DESC',
    'D3D12_FILTER_MAXIMUM_MIN_MAG_MIP_LINEAR',
    'D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ',
    'D3D12_COMPARISON_FUNC_LESS_EQUAL',
    'D3D12_TILE_COPY_FLAG_LINEAR_BUFFER_TO_SWIZZLED_TILED_RESOURCE',
    'DXGI_FORMAT_B8G8R8A8_UNORM_SRGB', 'D3D12_SHADER_VISIBILITY_HULL',
    'D3D11_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST',
    'D3D12_RESOURCE_FLAG_VIDEO_DECODE_REFERENCE_ONLY',
    'D3D12_LOGIC_OP_OR_INVERTED', 'D3D12_DRED_ALLOCATION_TYPE_PASS',
    'D3D12_DRED_ALLOCATION_TYPE_METACOMMAND',
    'D3D12_QUERY_TYPE_PIPELINE_STATISTICS',
    'D3D12_ROOT_SIGNATURE_FLAGS', 'DXGI_FORMAT_BC3_UNORM_SRGB',
    'D3D12_STATE_SUBOBJECT_TYPE_HIT_GROUP',
    'D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST',
    'D3D_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST',
    'D3D_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST',
    'DXGI_FORMAT_D24_UNORM_S8_UINT',
    'D3D12_AUTO_BREADCRUMB_OP_CLEARDEPTHSTENCILVIEW',
    'D3D12_AUTO_BREADCRUMB_OP_DISPATCHRAYS',
    'D3D12_ROOT_SIGNATURE_FLAG_DENY_DOMAIN_SHADER_ROOT_ACCESS',
    'D3D12_BLEND_SRC_ALPHA_SAT',
    'D3D12_FEATURE_GPU_VIRTUAL_ADDRESS_SUPPORT',
    'ID3D12VersionedRootSignatureDeserializer',
    'D3D12_ROOT_SIGNATURE_DESC', 'D3D12_FEATURE_SERIALIZATION',
    'DXGI_FORMAT_R32G32B32_FLOAT',
    'DXGI_FORMAT_R24_UNORM_X8_TYPELESS',
    '__MIDL___MIDL_itf_d3d12_0000_0003_0006', 'D3D12_TEX2D_SRV',
    'D3D12_TEX2D_ARRAY_RTV', 'D3D12_STENCIL_OP_INCR_SAT',
    'D3D11_PRIMITIVE_TOPOLOGY_POINTLIST',
    'DXGI_FORMAT_R32G32B32A32_FLOAT',
    'DXGI_FORMAT_B8G8R8X8_UNORM_SRGB',
    'D3D12_UAV_DIMENSION_TEXTURE3D', 'D3D12_LIFETIME_STATE',
    'D3D12_STATE_SUBOBJECT_TYPE_LOCAL_ROOT_SIGNATURE',
    'ID3D12Device8', 'DXGI_FORMAT_R16G16B16A16_FLOAT',
    'D3D12_BUFFER_UAV_FLAG_RAW', 'D3D12_SHADER_BYTECODE',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_CLONE',
    'D3D12_FILTER_COMPARISON_ANISOTROPIC',
    'D3D12_RESOURCE_STATE_INDEX_BUFFER',
    'D3D12_DRED_ALLOCATION_TYPE_RESOURCE', 'D3D_PRIMITIVE_TOPOLOGY',
    'D3D12_RESIDENCY_FLAGS',
    'D3D11_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST',
    'ID3D12CommandSignature', 'D3D12_ROOT_PARAMETER_TYPE',
    'D3D12_DRED_ENABLEMENT', 'D3D12_RESOURCE_STATE_GENERIC_READ',
    'D3D12_RESOLVE_MODE_DECOMPRESS', 'D3D12_SUBRESOURCE_TILING',
    'D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_RAYS',
    'D3D12_SHADER_CACHE_KIND_FLAG_APPLICATION_MANAGED',
    'D3D12_STATE_SUBOBJECT_TYPE_NODE_MASK',
    'D3D12_SHADER_VISIBILITY_AMPLIFICATION',
    'D3D12_RTV_DIMENSION_TEXTURE1D',
    'D3D12_HEAP_FLAG_SHARED_CROSS_ADAPTER',
    'D3D12_SHADER_CACHE_FLAG_NONE',
    'D3D12_AUTO_BREADCRUMB_OP_EXECUTEINDIRECT',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0007',
    'D3D12_BARRIER_LAYOUT_VIDEO_ENCODE_READ',
    'D3D12_RESIDENCY_PRIORITY_LOW', 'ID3D12Device4',
    'D3D12_MEMORY_POOL_L1',
    'D3D12_ROOT_SIGNATURE_FLAG_DENY_VERTEX_SHADER_ROOT_ACCESS',
    'D3D12_AUTO_BREADCRUMB_OP_COPYTEXTUREREGION',
    'DXGI_FORMAT_BC7_UNORM', 'D3D12_AUTO_BREADCRUMB_NODE1',
    'D3D12_SRV_DIMENSION_TEXTURE2DMS', 'DXGI_FORMAT_BC4_SNORM',
    'D3D12_BACKGROUND_PROCESSING_MODE_ALLOWED',
    'DXGI_FORMAT_R16G16B16A16_TYPELESS',
    'D3D12_ROOT_SIGNATURE_FLAG_DENY_AMPLIFICATION_SHADER_ROOT_ACCESS',
    'D3D12_MEASUREMENTS_ACTION_KEEP_ALL',
    'ID3D12RootSignatureDeserializer',
    'D3D12_RAYTRACING_GEOMETRY_TRIANGLES_DESC',
    'D3D12_DRED_AUTO_BREADCRUMBS_OUTPUT1', 'DXGI_FORMAT_R8_UINT',
    'D3D12_SHADER_CACHE_KIND_FLAGS', 'D3D12_COMMAND_LIST_FLAG_NONE',
    'D3D12_AUTO_BREADCRUMB_OP_EMITRAYTRACINGACCELERATIONSTRUCTUREPOSTBUILDINFO',
    'D3D12_COMMAND_LIST_TYPE_BUNDLE',
    'D3D12_PIPELINE_STATE_STREAM_DESC',
    'D3D_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST',
    'D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ',
    'ID3D12DeviceRemovedExtendedData', 'ID3D12Tools',
    'D3D12_RESIDENCY_PRIORITY_HIGH', 'D3D12_TILE_RANGE_FLAG_NULL',
    'D3D12_SHADING_RATE_COMBINER_PASSTHROUGH',
    'D3D12_PROTECTED_SESSION_STATUS_OK',
    'D3D12_VERSIONED_ROOT_SIGNATURE_DESC',
    'DXGI_FORMAT_R10G10B10A2_UNORM', 'D3D12_TEXCUBE_ARRAY_SRV',
    'D3D12_VERTEX_BUFFER_VIEW', 'D3D12_PREDICATION_OP',
    'ID3D12Object', 'D3D12_HEAP_FLAG_CREATE_NOT_ZEROED',
    'D3D12_RESOURCE_STATE_UNORDERED_ACCESS',
    'D3D12_DRED_ENABLEMENT_FORCED_OFF', 'DXGI_FORMAT_BC1_TYPELESS',
    'D3D12_FEATURE_D3D12_OPTIONS6', 'D3D12_FEATURE_D3D12_OPTIONS4',
    'D3D12_FEATURE_DISPLAYABLE', 'D3D12_TEX2D_UAV',
    'D3D12_SHADER_VISIBILITY_GEOMETRY', 'D3D12_TEX2DMS_RTV',
    'D3D12_DISCARD_REGION',
    'D3D12_INPUT_CLASSIFICATION_PER_INSTANCE_DATA',
    'D3D_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST',
    'DXGI_FORMAT_R16G16_UINT',
    'D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP',
    'D3D12_DESCRIPTOR_RANGE_FLAG_DESCRIPTORS_VOLATILE',
    'D3D12_RAYTRACING_GEOMETRY_FLAG_NO_DUPLICATE_ANYHIT_INVOCATION',
    'D3D12_QUERY_HEAP_TYPE_TIMESTAMP', 'D3D12_QUERY_HEAP_DESC',
    'D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG1',
    'DXGI_FORMAT_R32G32B32_SINT', 'D3D12_LOGIC_OP_NOOP',
    'D3D12_LOGIC_OP_COPY',
    'D3D_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST',
    'D3D12_FEATURE_SHADER_MODEL',
    'D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPE_COUNT',
    'D3D12_SHADER_VISIBILITY_DOMAIN', 'D3D12_AUTO_BREADCRUMB_NODE',
    'D3D11_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST',
    'D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_GENERIC_READ',
    'D3D12_FILTER_MINIMUM_MIN_MAG_MIP_POINT',
    'D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME2',
    'D3D12_RESOLVE_MODE_AVERAGE',
    '__MIDL___MIDL_itf_d3d12_0000_0003_0003',
    'D3D12_FILTER_MIN_MAG_LINEAR_MIP_POINT',
    'D3D12_HEAP_FLAG_ALLOW_ONLY_RT_DS_TEXTURES',
    'D3D12_SHADER_RESOURCE_VIEW_DESC', 'D3D12_UAV_DIMENSION',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_SERIALIZATION',
    'D3D12_AUTO_BREADCRUMB_OP_CLEARUNORDEREDACCESSVIEW',
    'D3D12_DEPTH_WRITE_MASK_ALL',
    'D3D_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST',
    'D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_PIPELINE_CONFIG',
    'D3D12_FEATURE_D3D12_OPTIONS13', 'D3D12_RESOLVE_MODE',
    'D3D12_BLEND_DEST_ALPHA',
    'D3D12_RESOURCE_STATE_VIDEO_PROCESS_READ',
    'D3D12_HEAP_FLAG_DENY_BUFFERS', 'D3D12_TILED_RESOURCE_COORDINATE',
    'D3D12_META_COMMAND_PARAMETER_TYPE_FLOAT',
    'D3D12_AUTO_BREADCRUMB_OP_RESOLVEMOTIONVECTORHEAP',
    'D3D_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST',
    'D3D12_BARRIER_LAYOUT_VIDEO_DECODE_READ',
    'D3D11_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST',
    'D3D12_BLEND_SRC_ALPHA', 'D3D12_LOGIC_OP_NAND',
    'D3D12_BLEND_OP_REV_SUBTRACT', 'D3D12_FEATURE_D3D12_OPTIONS20',
    'D3D12_PIPELINE_STATE_FLAG_NONE', 'D3D12_DSV_DIMENSION_UNKNOWN',
    'D3D12_RESOURCE_ALIASING_BARRIER',
    'D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST',
    'D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP',
    'D3D12_DESCRIPTOR_HEAP_TYPE_DSV', 'D3D12_LOGIC_OP_CLEAR',
    'D3D12_SHADER_VISIBILITY_ALL', 'D3D12_DSV_DIMENSION',
    '__MIDL___MIDL_itf_d3d12_0000_0048_0002',
    'D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ', 'D3D12_BLEND_OP_MIN',
    'D3D12_QUERY_HEAP_TYPE_VIDEO_DECODE_STATISTICS',
    'D3D12_QUERY_TYPE_SO_STATISTICS_STREAM2',
    'D3D12_FEATURE_EXISTING_HEAPS',
    'D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSIONPOLICY',
    'D3D12_SUBRESOURCE_FOOTPRINT', 'ID3D12GraphicsCommandList4',
    'D3D12_RESOURCE_FLAG_ALLOW_DEPTH_STENCIL',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_MINIMIZE_MEMORY',
    'DXGI_FORMAT_BC5_TYPELESS', 'D3D12_RESIDENCY_PRIORITY_MINIMUM',
    'D3D12_RESOURCE_BARRIER_FLAG_NONE', 'D3D_ROOT_SIGNATURE_VERSION',
    'D3D12_FEATURE_COMMAND_QUEUE_PRIORITY',
    'D3D12_CONSTANT_BUFFER_VIEW_DESC',
    'D3D12_ROOT_PARAMETER_TYPE_CBV',
    'D3D12_GRAPHICS_STATE_OM_RENDER_TARGETS',
    'D3D12_STENCIL_OP_REPLACE', 'D3D12_BARRIER_LAYOUT_RESOLVE_SOURCE',
    'D3D12_GRAPHICS_STATE_VIEW_INSTANCE_MASK',
    'D3D12_UAV_DIMENSION_TEXTURE2DARRAY',
    'D3D12_HEAP_FLAG_ALLOW_WRITE_WATCH',
    'D3D12_FILTER_MAXIMUM_MIN_POINT_MAG_MIP_LINEAR',
    'D3D12_TILE_COPY_FLAGS', 'D3D12_SRV_DIMENSION_BUFFER',
    'D3D12_META_COMMAND_PARAMETER_DESC',
    'D3D12_ROOT_DESCRIPTOR_FLAG_NONE',
    'D3D12_BACKGROUND_PROCESSING_MODE_DISABLE_PROFILING_BY_SYSTEM',
    'D3D12_CULL_MODE_NONE',
    'D3D12_DRED_ALLOCATION_TYPE_PIPELINE_STATE', 'DXGI_FORMAT_Y416',
    'D3D12_MULTIPLE_FENCE_WAIT_FLAG_NONE',
    'ID3D12GraphicsCommandList2', 'DXGI_FORMAT_BC5_UNORM',
    'DXGI_FORMAT_Y410',
    'D3D12_AUTO_BREADCRUMB_OP_CLEARRENDERTARGETVIEW',
    'D3D12_RAYTRACING_GEOMETRY_TYPE_PROCEDURAL_PRIMITIVE_AABBS',
    'D3D12_LOGIC_OP', 'D3D12_FEATURE_D3D12_OPTIONS',
    'D3D12_RESOURCE_BARRIER_FLAGS', 'DXGI_FORMAT_NV11',
    'D3D12_RESOURCE_STATE_RESOLVE_SOURCE', 'D3D12_DESCRIPTOR_RANGE1',
    'D3D12_FILTER_MAXIMUM_MIN_LINEAR_MAG_MIP_POINT', 'ID3D10Blob',
    'D3D12_TEXTURE_LAYOUT_64KB_STANDARD_SWIZZLE', 'DXGI_FORMAT_NV12',
    'D3D12_SHADING_RATE_4X2', 'D3D12_FENCE_FLAG_SHARED',
    'D3D12_UAV_DIMENSION_UNKNOWN', 'D3D12_TILE_COPY_FLAG_NO_HAZARD',
    'D3D12_GRAPHICS_STATE_GRAPHICS_ROOT_SIGNATURE',
    'D3D12_ROOT_SIGNATURE_FLAG_DENY_HULL_SHADER_ROOT_ACCESS',
    'D3D12_ELEMENTS_LAYOUT', 'D3D12_RENDER_TARGET_VIEW_DESC',
    'D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP',
    'D3D12_DESCRIPTOR_RANGE_TYPE_CBV', 'D3D12_FILTER_ANISOTROPIC',
    'D3D12_SRV_DIMENSION_TEXTURE2DMSARRAY', 'D3D12_CULL_MODE_BACK',
    'D3D12_GRAPHICS_PIPELINE_STATE_DESC',
    'D3D_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST',
    'D3D12_SHADER_CACHE_CONTROL_FLAG_ENABLE', 'DXGI_FORMAT_R8_UNORM',
    'D3D12_BARRIER_LAYOUT_RESOLVE_DEST',
    'D3D12_DRED_BREADCRUMB_CONTEXT',
    'D3D12_MEASUREMENTS_ACTION_DISCARD_PREVIOUS',
    'D3D12_RESOURCE_STATES', 'D3D12_BARRIER_LAYOUT_UNDEFINED',
    'D3D12_RESIDENCY_PRIORITY_NORMAL',
    'D3D12_RESOURCE_ALLOCATION_INFO1', 'D3D12_BLEND_INV_SRC1_COLOR',
    'D3D12_UAV_DIMENSION_TEXTURE2D', 'DXGI_FORMAT_BC6H_SF16',
    'D3D12_SHADER_CACHE_FLAG_USE_WORKING_DIR',
    'D3D12_FILTER_MINIMUM_MIN_LINEAR_MAG_POINT_MIP_LINEAR',
    'D3D12_BARRIER_LAYOUT_RENDER_TARGET',
    'D3D11_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST',
    'D3D11_PRIMITIVE_TOPOLOGY_UNDEFINED',
    'D3D12_WRITEBUFFERIMMEDIATE_MODE_MARKER_IN',
    'D3D12_BARRIER_LAYOUT_DEPTH_STENCIL_READ',
    'D3D12_COMMAND_LIST_TYPE',
    'D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_INPUTS',
    'D3D11_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST',
    'D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP',
    'D3D12_AUTO_BREADCRUMB_OP_ENCODEFRAME',
    'D3D12_SRV_DIMENSION_TEXTURE1D',
    'D3D12_RESOURCE_STATE_INDIRECT_ARGUMENT',
    'D3D11_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST',
    'D3D12_RAYTRACING_GEOMETRY_DESC',
    'D3D_PRIMITIVE_TOPOLOGY_LINELIST_ADJ',
    'D3D12_PRIMITIVE_TOPOLOGY_TYPE_LINE',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0003',
    'DXGI_FORMAT_BC2_UNORM_SRGB',
    'D3D12_COMMAND_LIST_TYPE_VIDEO_ENCODE', 'D3D12_TEX1D_ARRAY_SRV',
    'D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_WRITE',
    'D3D12_SHADER_CACHE_KIND_FLAG_IMPLICIT_DRIVER_MANAGED',
    'D3D12_HEAP_TYPE', 'D3D12_MEASUREMENTS_ACTION', 'D3D12_CULL_MODE',
    'DXGI_FORMAT_BC3_TYPELESS',
    'DXGI_FORMAT_R32_FLOAT_X8X24_TYPELESS',
    'D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_UNORDERED_ACCESS',
    'D3D12_BACKGROUND_PROCESSING_MODE_ALLOW_INTRUSIVE_MEASUREMENTS',
    'D3D11_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST',
    'D3D12_ROOT_SIGNATURE_FLAG_LOCAL_ROOT_SIGNATURE',
    'D3D12_DEPTH_STENCILOP_DESC',
    'D3D12_FILTER_MIN_LINEAR_MAG_MIP_POINT', 'D3D12_LOGIC_OP_AND',
    'D3D_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST',
    'D3D12_STATE_SUBOBJECT', 'D3D12_FEATURE_FORMAT_INFO',
    'DXGI_FORMAT_R32G32_FLOAT', 'D3D12_RESOURCE_DIMENSION_TEXTURE2D',
    'D3D12_PRIMITIVE_TOPOLOGY_TYPE_UNDEFINED',
    'D3D12_WRITEBUFFERIMMEDIATE_MODE', 'DXGI_FORMAT_R32G32_UINT',
    'D3D12_HEAP_FLAG_ALLOW_ONLY_BUFFERS',
    'D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COPY_DEST',
    'D3D12_INPUT_LAYOUT_DESC', 'D3D12_LOGIC_OP_XOR', 'ID3D12Device',
    'D3D12_SO_DECLARATION_ENTRY', 'DXGI_FORMAT_R16G16B16A16_SINT',
    'D3D12_DEPTH_WRITE_MASK', 'D3D12_TILE_MAPPING_FLAGS',
    'D3D12_SHADER_VISIBILITY',
    'D3D12_DRED_ALLOCATION_TYPE_COMMAND_POOL',
    'D3D12_BARRIER_LAYOUT_COMPUTE_QUEUE_COMMON',
    'DXGI_FORMAT_R8G8B8A8_UNORM_SRGB',
    'D3D_PRIMITIVE_TOPOLOGY_UNDEFINED',
    'D3D12_UAV_DIMENSION_TEXTURE1D', 'D3D12_STENCIL_OP_INCR',
    'D3D12_COMMAND_QUEUE_FLAG_NONE', 'DXGI_FORMAT_B4G4R4A4_UNORM',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0001',
    'D3D12_LOGIC_OP_OR_REVERSE', 'DXGI_FORMAT_UNKNOWN',
    'D3D12_GRAPHICS_STATE_OM_BLEND_FACTOR',
    'D3D12_FEATURE_D3D12_OPTIONS2',
    'D3D12_RESIDENCY_PRIORITY_MAXIMUM', 'DXGI_FORMAT_BC1_UNORM_SRGB',
    'DXGI_FORMAT_FORCE_UINT', 'D3D12_ROOT_PARAMETER1',
    'D3D12_HEAP_FLAG_ALLOW_DISPLAY', 'D3D12_DESCRIPTOR_RANGE',
    'D3D12_RESOURCE_STATE_SHADING_RATE_SOURCE',
    'DXGI_FORMAT_R16_SINT',
    'D3D12_FEATURE_PROTECTED_RESOURCE_SESSION_TYPES',
    'DXGI_FORMAT_R32G32B32A32_SINT',
    'D3D12_STATE_SUBOBJECT_TYPE_RAYTRACING_SHADER_CONFIG',
    'DXGI_FORMAT_420_OPAQUE', 'D3D12_PLACED_SUBRESOURCE_FOOTPRINT',
    'D3D12_META_COMMAND_PARAMETER_STAGE_CREATION',
    'D3D12_GRAPHICS_STATE_IA_VERTEX_BUFFERS',
    'DXGI_FORMAT_BC7_TYPELESS', 'ID3D12DescriptorHeap',
    'D3D12_BUFFER_UAV_FLAG_NONE', 'ID3D12Device10',
    'D3D12_DRIVER_MATCHING_IDENTIFIER_INCOMPATIBLE_VERSION',
    'DXGI_FORMAT_D32_FLOAT_S8X24_UINT', 'D3D12_TEX2D_ARRAY_SRV',
    'D3D12_INPUT_CLASSIFICATION',
    'D3D12_SHADING_RATE_COMBINER_OVERRIDE',
    'D3D12_ROOT_PARAMETER_TYPE_DESCRIPTOR_TABLE',
    'D3D12_DESCRIPTOR_RANGE_FLAG_NONE', 'ID3D12MetaCommand',
    'D3D12_BLEND_OP_ADD', 'D3D12_CLEAR_FLAG_DEPTH',
    'D3D12_MEASUREMENTS_ACTION_COMMIT_RESULTS_HIGH_PRIORITY',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_PREBUILD_INFO',
    'D3D12_QUERY_TYPE_TIMESTAMP',
    'D3D12_AUTO_BREADCRUMB_OP_EXECUTEMETACOMMAND',
    'DXGI_FORMAT_B8G8R8A8_TYPELESS',
    'D3D_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PREFER_FAST_BUILD',
    'D3D12_COMMAND_LIST_FLAGS', '__LUID',
    'D3D12_RESOLVE_MODE_DECODE_SAMPLER_FEEDBACK',
    'D3D12_DESCRIPTOR_HEAP_TYPE', 'D3D12_ROOT_SIGNATURE_FLAG_NONE',
    'D3D12_STATIC_BORDER_COLOR',
    'D3D12_AUTO_BREADCRUMB_OP_DECODEFRAME1',
    'D3D12_BARRIER_LAYOUT_COPY_DEST', 'D3D12_ELEMENTS_LAYOUT_ARRAY',
    'D3D12_MIP_REGION', 'D3D12_LIFETIME_STATE_IN_USE',
    'DXGI_FORMAT_YUY2', 'D3D12_FEATURE_D3D12_OPTIONS3',
    'D3D12_DRED_ENABLEMENT_FORCED_ON',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER',
    'D3D12_SRV_DIMENSION_TEXTURECUBE', 'D3D12_DSV_FLAG_NONE',
    'D3D11_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST',
    'D3D12_RESOURCE_FLAG_DENY_SHADER_RESOURCE',
    'D3D12_STREAM_OUTPUT_DESC',
    'D3D12_RENDER_PASS_ENDING_ACCESS_TYPE',
    'D3D12_RTV_DIMENSION_TEXTURE2DMSARRAY',
    'D3D12_AUTO_BREADCRUMB_OP_DISPATCHMESH',
    'D3D12_RAYTRACING_GEOMETRY_TYPE', 'D3D12_HEAP_FLAGS',
    'D3D10_PRIMITIVE_TOPOLOGY_LINELIST_ADJ',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_COPY_MODE_COMPACT',
    'D3D12_AUTO_BREADCRUMB_OP_RESOLVESUBRESOURCEREGION',
    'D3D12_TEXTURE_LAYOUT_64KB_UNDEFINED_SWIZZLE',
    'DXGI_FORMAT_SAMPLER_FEEDBACK_MIN_MIP_OPAQUE', 'D3D12_TEX3D_SRV',
    'D3D11_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST',
    'ID3D12Fence', 'D3D12_DSV_DIMENSION_TEXTURE1DARRAY',
    'D3D12_GRAPHICS_STATE_PIPELINE_STATE',
    'D3D12_BARRIER_LAYOUT_VIDEO_PROCESS_READ',
    'D3D12_DRIVER_MATCHING_IDENTIFIER_UNRECOGNIZED',
    'D3D_ROOT_SIGNATURE_VERSION_1_0', 'D3D12_DSV_FLAGS',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_DECODER_HEAP',
    'D3D12_TILE_RANGE_FLAG_SKIP', 'D3D_PRIMITIVE_TOPOLOGY_POINTLIST',
    'D3D12_WRITEBUFFERIMMEDIATE_PARAMETER',
    'D3D12_PRIMITIVE_TOPOLOGY_TYPE_TRIANGLE', 'D3D12_TEX1D_ARRAY_RTV',
    'D3D12_FEATURE_D3D12_OPTIONS11',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_PROCESSOR',
    'D3D12_DRED_ALLOCATION_TYPE_VIDEO_ENCODER_HEAP',
    'D3D12_AUTO_BREADCRUMB_OP_COPYRAYTRACINGACCELERATIONSTRUCTURE',
    'D3D11_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST',
    'D3D12_SERIALIZED_DATA_RAYTRACING_ACCELERATION_STRUCTURE',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_BUILD_FLAG_PERFORM_UPDATE',
    'D3D12_GRAPHICS_STATE_OM_STENCIL_REF',
    'D3D12_DEPTH_STENCIL_VIEW_DESC', 'DXGI_FORMAT_Y210',
    'D3D12_STREAM_OUTPUT_BUFFER_VIEW',
    'D3D12_DESCRIPTOR_RANGE_TYPE_UAV',
    '__MIDL___MIDL_itf_d3d12_0000_0003_0004', 'ID3D12Resource',
    'DXGI_FORMAT_R16G16_SINT',
    'D3D12_AUTO_BREADCRUMB_OP_BUILDRAYTRACINGACCELERATIONSTRUCTURE',
    'D3D12_INDEX_BUFFER_STRIP_CUT_VALUE_DISABLED',
    'D3D12_LOGIC_OP_NOR', 'D3D12_PROTECTED_RESOURCE_SESSION_DESC1',
    'D3D12_TEXTURE_ADDRESS_MODE_BORDER', 'D3D12_SHADING_RATE_4X4',
    'DXGI_FORMAT_R10G10B10A2_UINT',
    'D3D12_STATIC_BORDER_COLOR_TRANSPARENT_BLACK',
    'D3D12_GRAPHICS_STATE_SO_TARGETS',
    'D3D12_ROOT_SIGNATURE_FLAG_ALLOW_INPUT_ASSEMBLER_INPUT_LAYOUT',
    'D3D12_ROOT_SIGNATURE_FLAG_SAMPLER_HEAP_DIRECTLY_INDEXED',
    'D3D12_PIPELINE_STATE_FLAG_TOOL_DEBUG',
    'D3D12_INDIRECT_ARGUMENT_DESC', 'D3D12_HEAP_TYPE_DEFAULT',
    'D3D_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST',
    'D3D12_BARRIER_LAYOUT', 'DXGI_FORMAT_R16G16_SNORM',
    'D3D12_QUERY_TYPE_SO_STATISTICS_STREAM3',
    'D3D12_RESOURCE_BARRIER_TYPE_UAV', 'D3D12_FEATURE_CROSS_NODE',
    'D3D12_TEX2DMS_SRV', 'D3D12_INDIRECT_ARGUMENT_TYPE_DISPATCH_MESH',
    'ID3D12Device7', 'DXGI_FORMAT_R32_SINT',
    'ID3D12GraphicsCommandList3',
    'D3D12_PROTECTED_RESOURCE_SESSION_FLAG_NONE',
    'D3D11_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST',
    'D3D12_RESOURCE_FLAGS', 'D3D12_CLEAR_VALUE',
    'D3D12_CPU_PAGE_PROPERTY_NOT_AVAILABLE',
    'D3D12_BARRIER_LAYOUT_GENERIC_READ',
    'D3D12_AUTO_BREADCRUMB_OP_COPYRESOURCE', 'ID3D12PipelineLibrary',
    'D3D12_QUERY_TYPE', 'D3D12_BLEND_OP_SUBTRACT',
    'D3D12_DRED_ALLOCATION_TYPE_CRYPTOSESSION',
    'D3D11_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST',
    'D3D12_RENDER_PASS_BEGINNING_ACCESS_TYPE_NO_ACCESS',
    'ID3D12LifetimeOwner', 'D3D12_SRV_DIMENSION_TEXTURE1DARRAY',
    'D3D12_META_COMMAND_PARAMETER_STAGE_INITIALIZATION',
    'D3D11_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST',
    'D3D12_RESOURCE_FLAG_VIDEO_ENCODE_REFERENCE_ONLY',
    'D3D12_TEXTURE_LAYOUT_ROW_MAJOR', 'D3D12_STENCIL_OP_KEEP',
    'DXGI_FORMAT_BC6H_UF16', 'D3D12_RTV_DIMENSION_TEXTURE3D',
    'D3D11_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST',
    'D3D12_BLEND_SRC_COLOR', 'D3D12_RESOURCE_STATE_STREAM_OUT',
    'D3D12_COMMAND_QUEUE_DESC',
    'D3D12_BARRIER_LAYOUT_DIRECT_QUEUE_COPY_SOURCE',
    'D3D12_SERIALIZED_DATA_TYPE', 'ID3D12Device6',
    'D3D12_LOGIC_OP_INVERT', 'D3D12_INDIRECT_ARGUMENT_TYPE',
    'D3D12_RESOURCE_STATE_VERTEX_AND_CONSTANT_BUFFER',
    'D3D12_AUTO_BREADCRUMB_OP_RESOLVEENCODEROUTPUTMETADATA',
    'D3D12_AUTO_BREADCRUMB_OP_ATOMICCOPYBUFFERUINT',
    'D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ',
    'D3D12_FEATURE_D3D12_OPTIONS19',
    'D3D12_QUERY_HEAP_TYPE_COPY_QUEUE_TIMESTAMP',
    'D3D12_RESOURCE_BARRIER_TYPE', 'D3D12_RANGE_UINT64',
    'DXGI_FORMAT_R8_TYPELESS',
    'D3D12_META_COMMAND_PARAMETER_TYPE_CPU_DESCRIPTOR_HANDLE_HEAP_TYPE_CBV_SRV_UAV',
    'D3D11_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST',
    'D3D12_DRIVER_MATCHING_IDENTIFIER_UNSUPPORTED_TYPE',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0004',
    '__MIDL___MIDL_itf_d3d12_0000_0048_0001',
    'D3D_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST',
    'D3D12_COMPARISON_FUNC_LESS', 'D3D12_MEMORY_POOL',
    'D3D12_INDIRECT_ARGUMENT_TYPE_CONSTANT_BUFFER_VIEW',
    'D3D12_DRED_ENABLEMENT_SYSTEM_CONTROLLED',
    'D3D12_RAYTRACING_ACCELERATION_STRUCTURE_POSTBUILD_INFO_DESC',
    'D3D12_SAMPLER_DESC', 'D3D12_ROOT_DESCRIPTOR_FLAG_DATA_STATIC',
    'D3D_PRIMITIVE_TOPOLOGY_LINESTRIP',
    '__MIDL___MIDL_itf_d3d12_0000_0001_0008',
    'DXGI_FORMAT_R24G8_TYPELESS',
    'D3D12_ELEMENTS_LAYOUT_ARRAY_OF_POINTERS',
    'D3D_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST',
    'DXGI_FORMAT_R32_FLOAT', 'ID3D12PipelineState',
    'D3D12_RTV_DIMENSION_TEXTURE2DMS', 'D3D12_TEX1D_ARRAY_UAV',
    'D3D12_SHADING_RATE_COMBINER', 'D3D12_DESCRIPTOR_HEAP_FLAG_NONE',
    'DXGI_FORMAT_B5G5R5A1_UNORM',
    'D3D12_CPU_PAGE_PROPERTY_WRITE_BACK',
    'D3D12_ROOT_PARAMETER_TYPE_32BIT_CONSTANTS',
    'D3D12_BUILD_RAYTRACING_ACCELERATION_STRUCTURE_DESC',
    'D3D12_BUFFER_UAV', 'D3D12_SHADING_RATE_COMBINER_SUM'
]

D3D_FEATURE_LEVEL_11_0 = 0xB000
D3D_FEATURE_LEVEL_12_0 = 0xC000